from ApiMethod import ApiMethod


class Polls(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Polls, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'polls.'

    def addVote(self, owner_id: str = None, poll_id: str = None, answer_ids: str = None, is_board: str = None) -> dict:
        """
        Отдает голос текущего пользователя за выбранный вариант ответа в указанном опросе.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит опрос.
        :param poll_id: идентификатор опроса.
        :param answer_ids: список идентификаторов ответа (для опроса с мультивыбором).
        :param is_board: 1 – опрос находится в обсуждении, 0 – опрос прикреплен к стене.

        :return: После успешного выполнения возвращает одно из следующих значений:   1 — если голос текущего
            пользователя был отдан за выбранный вариант ответа;  0 — если текущий пользователь уже голосовал в
            указанном опрос
        """

        params = locals()
        method_name = self._base_method + 'addVote'
        return self._call(method_name, params)

    def create(self, question: str = None, is_anonymous: str = None, is_multiple: str = None, end_date: str = None,
               owner_id: str = None, add_answers: str = None, photo_id: str = None, background_id: str = None) -> dict:
        """
        Позволяет создавать опросы, которые впоследствии можно прикреплять к записям на странице пользователя или
        сообщества.

        :param question: текст вопроса
        :param is_anonymous: 1 – анонимный опрос, список проголосовавших недоступен;  0 – опрос публичный, список
            проголосовавших доступен;  По умолчанию – 0.
        :param is_multiple: 1 — для создания опроса с мультивыбором.
        :param end_date: дата завершения опроса в Unixtime.
        :param owner_id: Если опрос будет добавлен в группу, необходимо передать отрицательный идентификатор
            группы. По умолчанию текущий пользователь.
        :param add_answers: список вариантов ответов, например: ["yes", "no", "maybe"]  Может быть не менее 1 и
            не более 10 вариантов ответа.
        :param photo_id: идентификатор фотографии для использования в качестве фона сниппета.
        :param background_id: идентификатор стандартного фона для сниппета.

        :return: В случае успешного создания опроса в качестве результата возвращается объект опроса
        """

        params = locals()
        method_name = self._base_method + 'create'
        return self._call(method_name, params)

    def deleteVote(self, owner_id: str = None, poll_id: str = None, answer_id: str = None,
                   is_board: str = None) -> dict:
        """
        Снимает голос текущего пользователя с выбранного варианта ответа в указанном опросе.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит опрос.
        :param poll_id: идентификатор опроса.
        :param answer_id: идентификатор варианта ответа.
        :param is_board: 1 – опрос находится в обсуждении, 0 – опрос прикреплен к стене.

        :return: После успешного выполнения возвращает одно из следующих значений:   1 — если голос текущего
            пользователя был снят с выбранного варианта ответа  0 — если текущий пользователь еще не голосовал в
            указанном опросе или указан не выбранный им вариант ответ
        """

        params = locals()
        method_name = self._base_method + 'deleteVote'
        return self._call(method_name, params)

    def edit(self, owner_id: str = None, poll_id: str = None, question: str = None, add_answers: str = None,
             edit_answers: str = None, delete_answers: str = None, end_date: str = None, photo_id: str = None,
             background_id: str = None) -> dict:
        """
        Позволяет редактировать созданные опросы.

        :param owner_id: идентификатор владельца опроса
        :param poll_id: идентификатор редактируемого опроса
        :param question: новый текст редактируемого опроса
        :param add_answers: список вариантов ответов, например: ["yes", "no", "maybe"]
        :param edit_answers: объект, содержащий варианты ответов, которые необходимо отредактировать;  ключ –
            идентификатор ответа, значение – новый текст ответа  Пример: {"382967099":"option1",
            "382967103":"option2"}
        :param delete_answers: список идентификаторов ответов, которые необходимо удалить, например: [382967099,
            382967103]
        :param end_date: дата завершения опроса в Unixtime.
        :param photo_id: идентификатор фотографии для сниппета.
        :param background_id: идентификатор стандартного фона для сниппета.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def getBackgrounds(self) -> dict:
        """
        Возвращает варианты фонового изображения для опросов.

        :return: Возвращает массив объектов, описывающих фоновое изображение опроса. Каждый из объектов содержит
            поля:   type (string) — тип фона. Возможные значения: gradient или tile.  angle (string) — (для type =
            gradient) угол градиента по оси X.  color (string) — HEX-код замещающего цвета (без #).  width (integer)
            — (для type = tile) ширина плитки паттерна.  height (integer) — (для type = tile) высота плитки паттерна.
            points (array) — (для type = gradient) точки градиента. Массив объектов, каждый из которых содержит поля
            position (number) — положение точки — и color (string) — HEX-код цвета точки.  id (integer) —
            идентификатор фона
        """

        params = locals()
        method_name = self._base_method + 'getBackgrounds'
        return self._call(method_name, params)

    def getById(self, owner_id: str = None, is_board: str = None, poll_id: str = None, extended: str = None,
                friends_count: str = None, fields: str = None, name_case: str = None) -> dict:
        """
        Возвращает детальную информацию об опросе по его идентификатору.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит опрос.
        :param is_board: 1 — опрос находится в обсуждении, 0 — опрос прикреплен к стене.  По умолчанию — 0.
        :param poll_id: идентификатор опроса.
        :param extended: 1 — возвращать дополнительную информацию о профилях пользователей.
        :param friends_count: число идентификаторов проголосовавших друзей, которые необходимо вернуть в ответе.
        :param fields: список дополнительных полей профилей. См. список возможных значений
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: После успешного выполнения возвращает объект опроса
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getPhotoUploadServer(self, owner_id: str = None) -> dict:
        """
        Возвращает адрес сервера для загрузки фоновой фотографии в опрос.

        :param owner_id: идентификатор владельца опроса.

        :return: Возвращает объект с единственным полем upload_url (string), содержащим URL для загрузки
            фотографии
        """

        params = locals()
        method_name = self._base_method + 'getPhotoUploadServer'
        return self._call(method_name, params)

    def getVoters(self, owner_id: str = None, poll_id: str = None, answer_ids: str = None, is_board: str = None,
                  friends_only: str = None, offset: str = None, count: str = None, fields: str = None,
                  name_case: str = None) -> dict:
        """
        Получает список идентификаторов пользователей, которые выбрали определенные варианты ответа в опросе.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит опрос.
        :param poll_id: идентификатор опроса.
        :param answer_ids: идентификаторы вариантов ответа.
        :param is_board: 1 – опрос находится в обсуждении, 0 – опрос прикреплен к стене.
        :param friends_only: указывает, необходимо ли возвращать только пользователей, которые являются друзьями
            текущего пользователя. Параметр может принимать следующие значения: 0 — возвращать всех пользователей в
            порядке убывания времени голосования; 1 — возвращать только друзей текущего пользователя в порядке
            убывания времени голосования.  Если параметр не был задан, то считается, что он равен 0.
        :param offset: смещение относительно начала списка, для выборки определенного подмножества. Если параметр
            не задан, то считается, что он равен 0.
        :param count: количество возвращаемых идентификаторов пользователей. Если параметр не задан, то
            считается, что он равен 100, если не задан параметр friends_only, в противном случае 10. Максимальное
            значение параметра 1000, если не задан параметр friends_only, в противном случае 100.
        :param fields: перечисленные через запятую поля анкет, необходимые для получения. Доступные значения:
            nickname, screen_name, sex, bdate (birthdate), city, country, timezone, photo, photo_medium, photo_big,
            has_mobile, rate, contacts, education, online, counters.
        :param name_case: падеж для склонения имени и фамилии пользователя. Возможные значения: именительный –
            nom, родительный – gen, дательный – dat, винительный – acc, творительный – ins, предложный – abl. По
            умолчанию nom.

        :return: После успешного выполнения для каждого варианта ответа возвращает объект со следующими полями:
            answer_id — идентификатор варианта ответа;  users — список идентификаторов пользователей с учетом
            параметров offset и count, которые проголосовали за данный вариант. Первый элемент списка - общее
            количество пользователей, проголосовавших за данный вариант.   При использовании параметра fields массив
            users будет состоять из объектов user, каждый из которых содержит набор полей, определенных в этом
            параметре. Значения uid, first_name и last_name возвращаются всегда, вне зависимости от выбранных полей и
            их количества.  см. Описание полей параметра user
        """

        params = locals()
        method_name = self._base_method + 'getVoters'
        return self._call(method_name, params)

    def savePhoto(self, photo: str = None, hash: str = None) -> dict:
        """
        Сохраняет фотографию, загруженную в опрос.

        :param photo: параметр, полученный в результате загрузки фотографии.
        :param hash: параметр, полученный в результате загрузки фотографии.

        :return: Возвращает идентификатор загруженной фотографии
        """

        params = locals()
        method_name = self._base_method + 'savePhoto'
        return self._call(method_name, params)




from ApiMethod import ApiMethod


class Streaming(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Streaming, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'streaming.'

    def getServerUrl(self) -> dict:
        """
        Позволяет получить данные для подключения к Streaming API.

        :return: Возвращает объект, который содержит следующие поля:   endpoint (string) — хост для подключения к
            серверу;  key (string) — ключ доступа. Ключ бессрочный и прекращает действовать только после получения
            нового ключа
        """

        params = locals()
        method_name = self._base_method + 'getServerUrl'
        return self._call(method_name, params)

    def getSettings(self) -> dict:
        """
        Позволяет получить значение порога для Streaming API.

        :return: Возвращает объект с единственным полем monthly_limit (string), которое содержит значение
            tier_1-tier_6 или unlimited и соответствует установленному порогу для приложения
        """

        params = locals()
        method_name = self._base_method + 'getSettings'
        return self._call(method_name, params)

    def getStats(self, type: str = None, interval: str = None, start_time: str = None, end_time: str = None) -> dict:
        """
        Позволяет получить статистику для подготовленных и доставленных событий Streaming API.

        :param type: тип статистики. Возможные значения:   received — события, полученные приложением;  prepared
            — события, сгенерированные со стороны ВКонтакте.
        :param interval: интервалы статистики. Возможные значения:   5m — пять минут. Максимальный период — 3 дня
            между start_time и end_time;  1h — один час. Максимальный период — 7 дней между start_time и end_time;
            24h — сутки. Максимальный период — 31 день между start_time и end_time.
        :param start_time: время начала отсчёта в Unixtime. По умолчанию: end_time минус сутки.
        :param end_time: время окончания отсчёта в Unixtime. По умолчанию: текущее время.

        :return: Возвращает массив объектов, каждый из которых содержит поля:   event_type (string) — тип
            событий. Возможные значения:   post — записи на стене;  comment — комментарии;  share — репосты.   stats
            (array) — значения статистики. Массив объектов, каждый из которых содержит оля:   timestamp (integer) —
            время, соответствующее значению;  value (integer) — значение
        """

        params = locals()
        method_name = self._base_method + 'getStats'
        return self._call(method_name, params)

    def getStem(self, word: str = None) -> dict:
        """
        Позволяет получить основу слова.

        :param word: слово, основу которого мы собираемся получить

        :return
        """

        params = locals()
        method_name = self._base_method + 'getStem'
        return self._call(method_name, params)

    def setSettings(self, monthly_tier: str = None) -> dict:
        """
        Позволяет задать значение порога для Streaming API.

        :param monthly_tier: значение порога в месяц. Возможные значения:   tier_1;  tier_2;  tier_3;  tier_4;
            tier_5;  tier_6;  unlimited.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'setSettings'
        return self._call(method_name, params)




class User:
    def __init__(self, json_dict):
        self.id = json_dict.get('id')
        self.first_name = json_dict.get('first_name')
        self.last_name = json_dict.get('last_name')
        self.deactivated = json_dict.get('deactivated')
        self.is_closed = json_dict.get('is_closed')
        self.can_access_closed = json_dict.get('can_access_closed')
        self.about = json_dict.get('about')
        self.activities = json_dict.get('activities')
        self.bdate = json_dict.get('bdate')
        self.blacklisted = json_dict.get('blacklisted')
        self.blacklisted_by_me = json_dict.get('blacklisted_by_me')
        self.books = json_dict.get('books')
        self.can_post = json_dict.get('can_post')
        self.can_see_all_posts = json_dict.get('can_see_all_posts')
        self.can_see_audio = json_dict.get('can_see_audio')
        self.can_send_friend_request = json_dict.get('can_send_friend_request')
        self.can_write_private_message = json_dict.get('can_write_private_message')
        self.career = json_dict.get('career')
        self.city = json_dict.get('city')
        self.common_count = json_dict.get('common_count')
        self.connections = json_dict.get('connections')
        self.contacts = json_dict.get('contacts')
        self.counters = json_dict.get('counters')
        self.country = json_dict.get('country')
        self.crop_photo = json_dict.get('crop_photo')
        self.domain = json_dict.get('domain')
        self.education = json_dict.get('education')
        self.exports = json_dict.get('exports')
        self.followers_count = json_dict.get('followers_count')
        self.friend_status = json_dict.get('friend_status')
        self.games = json_dict.get('games')
        self.has_mobile = json_dict.get('has_mobile')
        self.has_photo = json_dict.get('has_photo')
        self.home_town = json_dict.get('home_town')
        self.interests = json_dict.get('interests')
        self.is_friend = json_dict.get('is_friend')
        self.is_hidden_from_feed = json_dict.get('is_hidden_from_feed')
        self.last_seen = json_dict.get('last_seen')
        self.lists = json_dict.get('lists')
        self.maiden_name = json_dict.get('maiden_name')
        self.military = json_dict.get('military')
        self.movies = json_dict.get('movies')
        self.music = json_dict.get('music')
        self.nickname = json_dict.get('nickname')
        self.occupation = json_dict.get('occupation')
        self.online = json_dict.get('online')
        self.personal = json_dict.get('personal')
        self.photo_50 = json_dict.get('photo_50')
        self.photo_100 = json_dict.get('photo_100')
        self.photo_200_orig = json_dict.get('photo_200_orig')
        self.photo_200 = json_dict.get('photo_200')
        self.photo_400_orig = json_dict.get('photo_400_orig')
        self.photo_id = json_dict.get('photo_id')
        self.photo_max = json_dict.get('photo_max')
        self.photo_max_orig = json_dict.get('photo_max_orig')
        self.quotes = json_dict.get('quotes')
        self.relatives = json_dict.get('relatives')
        self.relation = json_dict.get('relation')
        self.schools = json_dict.get('schools')
        self.screen_name = json_dict.get('screen_name')
        self.sex = json_dict.get('sex')
        self.site = json_dict.get('site')
        self.status = json_dict.get('status')
        self.timezone = json_dict.get('timezone')
        self.trending = json_dict.get('trending')
        self.tv = json_dict.get('tv')
        self.universities = json_dict.get('universities')
        self.verified = json_dict.get('verified')
        self.wall_default = json_dict.get('wall_default')

class Media:
    def __init__(self):
        pass


from ApiMethod import ApiMethod


class LeadForms(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(LeadForms, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'leadForms.'

    def create(self, group_id: str = None, name: str = None, title: str = None, description: str = None,
               questions: str = None, policy_link_url: str = None, photo: str = None, confirmation: str = None,
               site_link_url: str = None, active: str = None, once_per_user: str = None, pixel_code: str = None,
               notify_admins: str = None, notify_emails: str = None) -> dict:
        """
        Создаёт форму сбора заявок.

        :param group_id: Идентификатор группы, в которой надо создать форму.
        :param name: Название формы (видно только администратору).
        :param title: Заголовок формы (видят пользователи).
        :param description: Описание формы.
        :param questions: Информация о вопросах формы. Массив структур следующего формата:   type — тип вопроса;
            label — заголовок вопроса (только для нестандартных вопросов);  key — уникальный ключ вопроса
            (необязательно; только для нестандартных вопросов);  options — массив возможных ответов на вопрос (только
            для нестандартных вопросов типа radio, select, checkbox);   Типы стандартных вопросов:   first_name —
            имя;  patronymic_name — отчество;  last_name — фамилия;  email — адрес электронной почты;  phone_number —
            номер телефона;  age — возраст;  birthday — день рождения;  location — город и страна.   Типы
            нестандартных вопросов:   input — простое текстовое поле (строка);  textarea — большое текстовое поле
            (абзац);  radio — выбор одного из нескольких вариантов;  checkbox — выбор нескольких вариантов;  select —
            выбор одного варианта из выпадающего списка.   options должен быть массивом структур, описывающих
            варианты ответа:   label — текст ответа;  key — ключ ответа (необязательно).   Пример:[     {
                  "type":"first_name"     },     {        "type":"input",        "label":"Кличка кота"     },     {
                  "type":"select",        "key":"favorite_color",        "label":"Любимый цвет",        "options":[{
                    "key":"red",          "label":"Красный"        },{          "key":"green",
                    "label":"Зелёный"        }]     },     {        "type":"radio",        "label":"Я ношу часы...",
                  "options":[{           "key":"left",           "label":"на левой руке"        },{
                     "key":"right",           "label":"на правой руке"        }]     },     {
                  "type":"checkbox",        "key":"visited_cities",        "label":"Города, в которых я был",
                  "options":[{           "label":"Екатеринбург"        },{           "label":"Волгоград"        },{
                     "label":"Санкт-Петербург"        }]     }  ]
        :param policy_link_url: Ссылка на политику конфиденциальности.
        :param photo: Обложка формы.  Используйте значение, полученное после загрузки фотографии на сервер. См.
            метод leadForms.getUploadURL.  Также можно переиспользовать существующую фотографию из другой формы.
            Используйте значение поля photo, которое возвращает метод leadForms.get или leadForms.list.
        :param confirmation: Текст подтверждения, который увидит пользователь после отправки формы.
        :param site_link_url: Ссылка на сайт или сообщество автора формы.
        :param active: Передайте 1, чтобы активировать форму сразу после создания. Пользователи могут оставлять
            заявки только в активных формах.
        :param once_per_user: Передайте 1, чтобы разрешить каждому пользователю заполнять форму только один раз.
        :param pixel_code: Передайте код пикселя ретаргетинга ВКонтакте в виде VK-RTRG-000000-XXXXX. По этому
            пикселю будет собираться аудитория пользователей, открывших форму. Подробнее о пикселе см. здесь.
        :param notify_admins: Передайте список идентификаторов пользователей, которым будут отправлены оповещения
            о заполнении пользователями формы. Оповещения могут быть отправлены только администраторам сообщества.
        :param notify_emails: Передайте список email-адресов, разделённых запятой, на которые будут отправлены
            оповещения о заполнении пользователями формы. Можно указать до 10 адресов.

        :return: Возвращается структура с информацией о созданной форме:   form_id — идентификатор формы;  url —
            ссылка на форму
        """

        params = locals()
        method_name = self._base_method + 'create'
        return self._call(method_name, params)

    def delete(self, group_id: str = None, form_id: str = None) -> dict:
        """
        Удаляет форму сбора заявок.

        :param group_id: Идентификатор группы, из которой надо удалить форму.
        :param form_id: Идентификатор удаляемой формы.

        :return: Возвращает идентификатор удалённой форм
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def get(self, group_id: str = None, form_id: str = None) -> dict:
        """
        Возвращает информацию о форме сбора заявок.

        :param group_id: Идентификатор группы, в которой находится форма.
        :param form_id: Идентификатор формы.

        :return: Возвращает структуру с информацией о форме. Значения полей см. в методе leadForms.create.
            Дополнительно возвращает следующие поля:   form_id — идентификатор формы;  leads_count — количество
            заявок;  url — ссылка на форму
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getLeads(self, group_id: str = None, form_id: str = None, limit: str = None,
                 next_page_token: str = None) -> dict:
        """
        Возвращает заявки формы.

        :param group_id: идентификатор сообщества, в котором находится форма.
        :param form_id: идентификатор формы.
        :param limit: количество возвращаемых заявок за один запрос.
        :param next_page_token: , полученная из предыдущего запроса для получения следующей порции результатов.

        :return: Возвращает массив структур со следующими полями:   lead_id — идентификатор заявки, уникальный в
            рамках сообщества, в котором находится форма;  user_id — идентификатор пользователя, оставившего заявку;
            date — дата и время оставления заявки в формате unix timestamp;  answers — информация об ответах на
            вопросы — массив структур со следующими полями:   key — ключ вопроса. Совпадает с типом стандартного
            вопроса (его полем type), или с ключом нестандартного вопроса (поле key). Для нестандартных вопросов, для
            которых не был задан ключ, будет использовано значение вида custom_0, где «0» — порядковый номер
            нестандартного вопроса, считая с 0.  answer — ответ на вопрос. Структура (для всех вопросов, кроме типа
            checkbox) или массив структур (для типа checkbox) со следующими полями:   key — ключ ответа (в случае,
            если был задан при создании формы);  value — текст ответа;    ad_id — идентификатор рекламного
            объявления, с которого пришла заявка (поле отсутствует в случае, если заявка пришла не из рекламного
            объявления)
        """

        params = locals()
        method_name = self._base_method + 'getLeads'
        return self._call(method_name, params)

    def getUploadURL(self) -> dict:
        """
        Возвращает URL для загрузки обложки для формы.

        :return: Возвращает URL для загрузки обложки для формы
        """

        params = locals()
        method_name = self._base_method + 'getUploadURL'
        return self._call(method_name, params)

    def list(self, group_id: str = None) -> dict:
        """
        Возвращает список форм сообщества.

        :param group_id: Идентификатор сообщества.

        :return: Возвращает массив структур с описанием форм. Подробнее о структуре описания формы см. метод
            leadForms.get
        """

        params = locals()
        method_name = self._base_method + 'list'
        return self._call(method_name, params)

    def update(self, group_id: str = None, form_id: str = None, name: str = None, title: str = None,
               description: str = None, questions: str = None, policy_link_url: str = None, photo: str = None,
               confirmation: str = None, site_link_url: str = None, active: str = None, once_per_user: str = None,
               pixel_code: str = None, notify_admins: str = None, notify_emails: str = None) -> dict:
        """
        Обновляет форму сбора заявок.

        :param group_id: Идентификатор группы, в которой надо обновить форму.
        :param form_id: Идентификатор формы, которую надо обновить.
        :param name: Новое название формы (видно только администратору).
        :param title: Новый заголовок формы (видят пользователи).
        :param description: Новое описание формы.
        :param questions: Новые вопросы формы. Подробнее см. метод leadForms.create.
        :param policy_link_url: Новая ссылка на политику конфиденциальности.
        :param photo: Новая обложка формы.
        :param confirmation: Новый текст подтверждения, который увидит пользователь после отправки формы.
        :param site_link_url: Новая ссылка на сайт или сообщество автора формы.
        :param active: Передайте 1, чтобы активировать форму. Пользователи могут оставлять заявки только в
            активных формах.
        :param once_per_user: Передайте 1, чтобы разрешить каждому пользователю заполнять форму только один раз.
        :param pixel_code: Новый код пикселя ретаргетинга ВКонтакте.
        :param notify_admins: Новый список идентификаторов пользователей, которым будут отправлены оповещения о
            заполнении пользователями формы. Оповещения могут быть отправлены только администраторам сообщества.
        :param notify_emails: Новый список email-адресов, разделённых запятой, на которые будут отправлены
            оповещения о заполнении пользователями формы. Можно указать до 10 адресов.

        :return: Возвращается структура с информацией об обновлённой форме:   form_id — идентификатор формы;  url
            — ссылка на форму
        """

        params = locals()
        method_name = self._base_method + 'update'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Apps(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Apps, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'apps.'



from ApiMethod import ApiMethod

class Ads(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Ads, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'ads.'

    def addOfficeUsers(self, account_id: str = None, data: str = None) -> dict:
        """
        Добавляет администраторов и/или наблюдателей в рекламный кабинет.

        :param account_id: идентификатор рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих добавляемых администраторов. Описание
            объектов user_specification см. ниже.

        :return: Возвращает массив значений - ответов на каждый запрос в массиве data. Соответствующее значение в
            выходном массиве равно true, если администратор успешно добавлен, и false в другом случае
        """

        params = locals()
        method_name = self._base_method + 'addOfficeUsers'
        return self._call(method_name, params)

    def checkLink(self, account_id: str = None, link_type: str = None, link_url: str = None,
                  campaign_id: str = None) -> dict:
        """
        Проверяет ссылку на рекламируемый объект.

        :param account_id: идентификатор рекламного кабинета.
        :param link_type: вид рекламируемого объекта:   community — сообщество;  post — запись в сообществе;
            application — приложение ВКонтакте;  video — видеозапись;  site — внешний сайт.
        :param link_url: ссылка на рекламируемый объект.
        :param campaign_id: id кампании, в которой будет создаваться объявление.

        :return: Возвращается структура со следующими полями:   status — статус ссылки:   allowed — ссылку
            допустимо использовать в рекламных объявлениях;  disallowed — ссылку недопустимо использовать для
            указанного вида рекламируемого объекта;  in_progress — ссылка проверяется, необходимо немного подождать.
            description (если status равен disallowed, необязательное поле) — описание причины недопустимости
            использования ссылки.  redirect_url (если конечная ссылка отличается от исходной и если status равен
            allowed) — конечная ссылка
        """

        params = locals()
        method_name = self._base_method + 'checkLink'
        return self._call(method_name, params)

    def createAds(self, account_id: str = None, data: str = None) -> dict:
        """
        Создает рекламные объявления.

        :param account_id: идентификатор рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих создаваемые объявления. Описание объектов
            ad_specification см. ниже.  Максимальное допустимое количество объявлений,  создаваемых с помощью одного
            запроса — 5. Если нужно больше, то можно использовать execute.  Пример значения data: [{
                "campaign_id": 123456,      "ad_format": 1,      "cost_type": 0,      "cpc": 2.00,
                "category1_id" : 5,      "title": "Test Title",      "link_url" : "https://mysite.com",      "name":
            "My ad"  }]

        :return: Возвращает массив объектов - ответов на каждый запрос в массиве data. Соответствующий объект в
            выходном массиве имеет свойство id, соответствующее id созданного объявления (или 0 в случае неудачи), а
            также, возможно, поля error_code и error_desc, описывающие ошибку, при ее возникновении. Наличие
            одновременно ненулевого id и error_code говорит о том, что объявление было создано, однако, возможно, не
            все параметры установлены (например, объявление не запущено)
        """

        params = locals()
        method_name = self._base_method + 'createAds'
        return self._call(method_name, params)

    def createCampaigns(self, account_id: str = None, data: str = None) -> dict:
        """
        Создает рекламные кампании.

        :param account_id: идентификатор рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих создаваемые кампании. Описание объектов
            campaign_specification см. ниже.

        :return: Возвращает массив ответов на запросы в массиве data. Соответствующий объект в выходном массиве
            содержит id созданной кампании (ноль в случае неудачи), и поля error_code и error_desc в случае
            возникновения ошибки. Ненулевой id и наличие error_code 602 говорит о том, что кампания создана, но,
            возможно, некоторые поля не были ей присвоены по причине их некорректности
        """

        params = locals()
        method_name = self._base_method + 'createCampaigns'
        return self._call(method_name, params)

    def createClients(self, account_id: str = None, data: str = None) -> dict:
        """
        Создаёт клиентов рекламного агентства.

        :param account_id: id рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих создаваемые кампании. Описание объектов
            client_specification см. ниже.

        :return: Возвращает массив ответов на запросы в массиве data. Соответствующий объект в выходном массиве
            содержит id созданного клиента (ноль в случае неудачи), и поля error_code и error_desc в случае
            возникновения ошибки. Ненулевой id и наличие error_code 602 говорит о том, что клиент создан, но,
            возможно, некоторые поля не были ему присвоены по причине их некорректности
        """

        params = locals()
        method_name = self._base_method + 'createClients'
        return self._call(method_name, params)

    def createLookalikeRequest(self, account_id: str = None, client_id: str = None, source_type: str = None,
                               retargeting_group_id: str = None) -> dict:
        """
        Создаёт запрос на поиск похожей аудитории.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  идентификатор клиента, для которого будет создаваться
            аудитория.
        :param source_type: Тип источника исходной аудитории. На данный момент может принимать единственное
            значение retargeting_group.
        :param retargeting_group_id: Только для источника типа retargeting_group: идентификатор аудитории
            ретаргетинга.

        :return: Поле request_id, в котором указан идентификатор созданного запроса на поиск похожей аудитории
        """

        params = locals()
        method_name = self._base_method + 'createLookalikeRequest'
        return self._call(method_name, params)

    def createTargetGroup(self, account_id: str = None, client_id: str = None, name: str = None, lifetime: str = None,
                          target_pixel_id: str = None, target_pixel_rules: str = None) -> dict:
        """
        Создает аудиторию для ретаргетинга рекламных объявлений на пользователей, которые посетили сайт рекламодателя
        (просмотрели информации о товаре, зарегистрировались и т.д.).

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого будет
            создаваться аудитория.
        :param name: название аудитории ретаргетинга — строка до 64 символов.
        :param lifetime: Количество дней, через которое пользователи, добавляемые в аудиторию, будут
            автоматически исключены из нее.
        :param target_pixel_id: идентификатор пикселя, если требуется собирать аудиторию с веб-сайта.
        :param target_pixel_rules: массив правил для пополнения аудитории из пикселя. Имеет вид:  [      {"type":
            args},      {"type": args},      ...      {"type": args}  ]

        :return: Возвращает объект со следующими полями:   id — идентификатор аудитории
        """

        params = locals()
        method_name = self._base_method + 'createTargetGroup'
        return self._call(method_name, params)

    def createTargetPixel(self, account_id: str = None, client_id: str = None, name: str = None, domain: str = None,
                          category_id: str = None) -> dict:
        """
        Создаёт пиксель ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого будет
            создаваться пиксель.
        :param name: название пикселя — строка до 64 символов.
        :param domain: домен сайта, на котором будет размещен пиксель.
        :param category_id: идентификатор категории сайта, на котором будет размещен пиксель. Для получения
            списка возможных идентификаторов следует использовать метод ads.getSuggestions (раздел
            interest_categories_v2).

        :return: Возвращает объект со следующими полями:   id — идентификатор пикселя  pixel — код для размещения
            на сайте рекламодател
        """

        params = locals()
        method_name = self._base_method + 'createTargetPixel'
        return self._call(method_name, params)

    def deleteAds(self, account_id: str = None, ids: str = None) -> dict:
        """
        Архивирует рекламные объявления.

        :param account_id: идентификатор рекламного кабинета.
        :param ids: сериализованный JSON-массив, содержащий идентификаторы объявлений.

        :return: Возвращает массив ответов на каждый запрос. Каждый ответ является либо 0, что означает успешное
            удаление, либо код ошибки
        """

        params = locals()
        method_name = self._base_method + 'deleteAds'
        return self._call(method_name, params)

    def deleteCampaigns(self, account_id: str = None, ids: str = None) -> dict:
        """
        Архивирует рекламные кампании.

        :param account_id: идентификатор рекламного кабинета.
        :param ids: сериализованный JSON-массив, содержащий id удаляемых кампаний.

        :return: Возвращает массив ответов на каждый запрос. Каждый ответ является либо 0, что означает успешное
            удаление, либо код ошибки
        """

        params = locals()
        method_name = self._base_method + 'deleteCampaigns'
        return self._call(method_name, params)

    def deleteClients(self, account_id: str = None, ids: str = None) -> dict:
        """
        Архивирует клиентов рекламного агентства.

        :param account_id: идентификатор рекламного кабинета.
        :param ids: сериализованный JSON-массив, содержащий id удаляемых клиентов.

        :return: Возвращает массив ответов на каждый запрос. Каждый ответ является либо 0, что означает успешное
            удаление, либо код ошибки
        """

        params = locals()
        method_name = self._base_method + 'deleteClients'
        return self._call(method_name, params)

    def deleteTargetGroup(self, account_id: str = None, client_id: str = None, target_group_id: str = None) -> dict:
        """
        Удаляет аудиторию ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого будет
            удаляться аудитория.
        :param target_group_id: идентификатор аудитории.

        :return: В случае успеха метод возвратит 1
        """

        params = locals()
        method_name = self._base_method + 'deleteTargetGroup'
        return self._call(method_name, params)

    def deleteTargetPixel(self, account_id: str = None, client_id: str = None, target_pixel_id: str = None) -> dict:
        """
        Удаляет пиксель ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого будет
            удаляться пиксель.
        :param target_pixel_id: идентификатор пикселя.

        :return: В случае успеха метод возвратит 1
        """

        params = locals()
        method_name = self._base_method + 'deleteTargetPixel'
        return self._call(method_name, params)

    def getAccounts(self) -> dict:
        """
        Возвращает список рекламных кабинетов.



        :return: Возвращает массив объектов, описывающих рекламные кабинеты. Каждый объект содержит следующие
            поля:  account_id  integerидентификатор рекламного кабинета. account_type  stringтип рекламного кабинета.
            Возможные значения:   general — обычный;  agency — агентский. account_status  integer, [0,1]статус
            рекламного кабинета. Возможные значения:   1 — активен;  0 — неактивен. access_role  stringправа
            пользователя в рекламном кабинете. Возможные значения:   admin — главный администратор;  manager —
            администратор;  reports — наблюдатель
        """

        params = locals()
        method_name = self._base_method + 'getAccounts'
        return self._call(method_name, params)

    def getAds(self, account_id: str = None, client_id: str = None, include_deleted: str = None,
               campaign_ids: str = None, ad_ids: str = None, limit: str = None, offset: str = None) -> dict:
        """
        Возвращает список рекламных объявлений.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Доступно и обязательно для рекламных агентств. Идентификатор клиента, у которого
            запрашиваются рекламные объявления.
        :param include_deleted: Флаг, задающий необходимость вывода архивных объявлений.   0 — выводить только
            активные объявления;  1 — выводить все объявления.
        :param campaign_ids: фильтр по рекламным кампаниям.  Сериализованный JSON-массив, содержащий id кампаний.
            Если параметр равен null, то будут выводиться рекламные объявления всех кампаний.
        :param ad_ids: фильтр по рекламным объявлениям.  Сериализованный JSON-массив, содержащий id объявлений.
            Если параметр равен null, то будут выводиться все рекламные объявления.
        :param limit: ограничение на количество возвращаемых объявлений. Используется, только если параметр
            ad_ids равен null, а параметр campaign_ids содержит id только одной кампании.
        :param offset: смещение. Используется в тех же случаях, что и параметр limit.

        :return: Возвращает массив объектов, описывающих основные характеристики объявления.  Дополнительные
            характеристики можно получить при помощи метода ads.getAdsLayout.  Каждый объект содержит следующие поля:
            id  integerидентификатор объявления. campaign_id  integerидентификатор кампании. ad_format  integerформат
            объявления. Возможные значения:   1 — изображение и текст;  2 — большое изображение;  3 — эксклюзивный
            формат;  4 — продвижение сообществ или приложений, квадратное изображение;  5 — приложение в новостной
            ленте (устаревший);  6 — мобильное приложение;  9 — запись в сообществе;  11 — адаптивный формат;  12 —
            истории. cost_type  integer, [0,1,3]тип оплаты. Возможные значения:   0 — оплата за переходы;  1 — оплата
            за показы;  3 — оптимизированная оплата за показы. cpc  integer(если cost_type = 0) цена за переход в
            копейках. cpm  integer(если cost_type = 1) цена за 1000 показов в копейках. ocpm  integer(если cost_type
            = 3) цена за действие для oCPM в копейках. goal_type  integer, [1,2,3]тип цели. Возможные значения:   1 —
            показы;  2 — переходы;  3 — отправка заявок;  5 — вступления в сообщество. impressions_limit
            integer(если задано) ограничение количества показов данного объявления на одного пользователя. Может
            присутствовать для некоторых форматов объявлений, для которых разрешена установка точного значения.
            impressions_limited  integer, [1](если задано) признак того, что количество показов объявления на одного
            пользователя ограничено. Может присутствовать для некоторых объявлений, для которых разрешена установка
            ограничения, но не разрешена установка точного значения. 1 — не более 100 показов на одного пользователя.
            ad_platform(если значение применимо к данному формату объявления) рекламные площадки, на которых будет
            показываться объявление. Возможные значения:   (если ad_format равен 1)   0 — ВКонтакте и сайты-партнёры;
            1 — только ВКонтакте.   (если ad_format равен 9)   all — все площадки;  desktop — полная версия сайта;
            mobile — мобильный сайт и приложения.   (если ad_format равен 11)   all — все площадки;  desktop — полная
            версия сайта;  mobile — мобильный сайт и приложения. ad_platform_no_wall  integer, [1]1 — для объявления
            задано ограничение «Не показывать на стенах сообществ». ad_platform_no_ad_network  integer, [1]1 — для
            объявления задано ограничение «Не показывать в рекламной сети». all_limit  integerобщий лимит объявления
            в рублях. 0 — лимит не задан. day_limit  integerдневной лимит объявления в рублях. 0 — лимит не задан.
            autobiddingавтоматическое управление ценой:   0 — выключено;  1 — включено.  флаг, может принимать
            значения 0 или 1 autobidding_max_cost  integerмаксимальное ограничение автоматической ставки в копейках
            category1_id  integerID тематики или подраздела тематики объявления. См. ads.getCategories. category2_id
            integerID тематики или подраздела тематики объявления. Дополнительная тематика. status  integerстатус
            объявления. Возможные значения:     0 — объявление остановлено;  1 — объявление запущено;  2 — объявление
            удалено. name  stringназвание объявления. approved  integerстатус модерации объявления. Возможные
            значения:     0 — объявление не проходило модерацию;  1 — объявление ожидает модерации;  2 — объявление
            одобрено;  3 — объявление отклонено. video  integer, [1]1 — объявление является видеорекламой.
            disclaimer_medical  integer, [1]1 — включено отображение предупреждения:  «Есть противопоказания.
            Требуется консультация специалиста.» disclaimer_specialist  integer, [1]1 — включено отображение
            предупреждения:  «Необходима консультация специалистов.» disclaimer_supplements  integer, [1]1 — включено
            отображение предупреждения:  «БАД. Не является лекарственным препаратом.» weekly_schedule_hours
            arrayрасписание показа объявления по часам. Массив из семи строк. Каждая из строк соответствует дню
            недели и содержит последовательность символов 0 или 1. 0 — не показывать объявление в час, номер которого
            равен позиции символа. 1 — показывать. weekly_schedule_use_holidays  integer, [0,1]1 — использовать
            расписание воскресенья в праздничные дни. events_retargeting_groups  arrayТолько для ad_format = 9 и 11.
            Описание событий, собираемых в группы ретаргетинга. Массив объектов, где ключом является id группы
            ретаргетинга, а значением - массив событий. Допустимые значений для событий:   1 — просмотр промопоста;
            2 — переход по ссылке или переход в сообщество;  3 — переход в сообщество;  4 — подписка на сообщество;
            5 — отписка от новостей сообщества;  6 — скрытие или жалоба;  10 — запуск видео;  11 — досмотр видео до
            3с;  12 — досмотр видео до 25%;  13 — досмотр видео до 50%;  14 — досмотр видео до 75%;  15 — досмотр
            видео до 100%;  20 — лайк продвигаемой записи;  21 — репост продвигаемой записи
        """

        params = locals()
        method_name = self._base_method + 'getAds'
        return self._call(method_name, params)

    def getAdsLayout(self, account_id: str = None, client_id: str = None, include_deleted: str = None,
                     campaign_ids: str = None, ad_ids: str = None, limit: str = None, offset: str = None) -> dict:
        """
        Возвращает описания внешнего вида рекламных объявлений.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Для рекламных агентств. Идентификатор клиента, у которого запрашиваются рекламные
            объявления.
        :param include_deleted: Флаг, задающий необходимость вывода архивных объявлений.   0 — выводить только
            активные объявления;  1 — выводить все объявления.
        :param campaign_ids: фильтр по рекламным кампаниям. Сериализованный JSON-массив, содержащий id кампаний.
            Если параметр равен null, то будут выводиться рекламные объявления всех кампаний.
        :param ad_ids: фильтр по рекламным объявлениям. Сериализованный JSON-массив, содержащий id объявлений.
            Если параметр равен null, то будут выводиться все рекламные объявления.
        :param limit: ограничение на количество возвращаемых объявлений. Используется, только если параметр
            ad_ids равен null, а параметр campaign_ids содержит id только одной кампании.
        :param offset: смещение. Используется в тех же случаях, что и параметр limit.

        :return: Возвращает массив объектов, описывающих дополнительные характеристики объявления.  Основные
            характеристики можно получить при помощи метода ads.getAds.  Каждый объект содержит следующие поля:  id
            integerидентификатор объявления. campaign_id integerидентификатор кампании. ad_format  integerформат
            объявления. Возможные значения:   1 — изображение и текст;  2 — большое изображение;  3 — эксклюзивный
            формат;  4 — продвижение сообществ или приложений, квадратное изображение;  5 — приложение в новостной
            ленте (устаревший);  6 — мобильное приложение;  7 — специальный формат приложений;  8 — специальный
            формат сообществ;  9 — запись в сообществе;  10 — витрина приложений;  11 — адаптивный формат. cost_type
            integer, [0,1,3]тип оплаты. Возможные значения:   0 — оплата за переходы;  1 — оплата за показы;  3 —
            оптимизированная оплата за показы. goal_type  integer, [1,2,3]тип цели. Возможные значения:   1 — показы;
            2 — переходы;  3 — отправка заявок. video  integer, [1]1 — объявление является видеорекламой.
            repeat_video  integer, [0,1]зацикливание видео. Возможные значения:   0 — не зацикливать видео;  1 —
            зацикливать видео. title stringзаголовок объявления. description  stringописание объявления. link_url
            stringссылка на рекламируемый объект. link_domain  stringдомен рекламируемого сайта. link_title
            stringзаголовок рядом с кнопкой/ссылкой. link_button stringидентификатор кнопки объявления. Список
            возможных значений. preview_link  stringссылка, перейдя по которой можно просмотреть рекламное объявление
            так, как оно выглядит на сайте. Ссылка доступна в течение 30 минут после выполнения метода
            ads.getAdsLayout. image_src  stringurl изображения объявления. image_src_2x  stringurl изображения
            двойного разрешения. icon_src  stringurl логотипа объявления. icon_src_2x  stringurl логотипа двойного
            разрешения
        """

        params = locals()
        method_name = self._base_method + 'getAdsLayout'
        return self._call(method_name, params)

    def getAdsTargeting(self, account_id: str = None, client_id: str = None, include_deleted: str = None,
                        campaign_ids: str = None, ad_ids: str = None, limit: str = None, offset: str = None) -> dict:
        """
        Возвращает параметры таргетинга рекламных объявлений

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Для рекламных агентств. id клиента, у которого запрашиваются рекламные объявления.
        :param include_deleted: Флаг, задающий необходимость вывода архивных объявлений.   0 — выводить только
            активные объявления;  1 — выводить все объявления.
        :param campaign_ids: фильтр по рекламным кампаниям.  Сериализованный JSON-массив, содержащий id кампаний.
            Если параметр равен null, то будут выводиться рекламные объявления всех кампаний.
        :param ad_ids: фильтр по рекламным объявлениям.  Сериализованный JSON-массив, содержащий id объявлений.
            Если параметр равен null, то будут выводиться все рекламные объявления.
        :param limit: ограничение на количество возвращаемых объявлений. Используется, только если параметр
            ad_ids равен null, а параметр campaign_ids содержит id только одной кампании.
        :param offset: смещение, необходимо для выборки определенного подмножества значений.

        :return: Возвращает массив объектов - описаний таргетинга объявлений.  Отрицательные id в поле cities
            означают id регионов, взятых с обратным знаком.  Поле count содержит размер целевой аудитории на момент
            сохранения объявления
        """

        params = locals()
        method_name = self._base_method + 'getAdsTargeting'
        return self._call(method_name, params)

    def getBudget(self, account_id: str = None) -> dict:
        """
        Возвращает текущий бюджет рекламного кабинета.

        :param account_id: идентификатор рекламного кабинета.

        :return: Возвращает единственное число — оставшийся бюджет в указанном рекламном кабинете
        """

        params = locals()
        method_name = self._base_method + 'getBudget'
        return self._call(method_name, params)

    def getCampaigns(self, account_id: str = None, client_id: str = None, include_deleted: str = None,
                     campaign_ids: str = None, fields: str = None) -> dict:
        """
        Возвращает список кампаний рекламного кабинета.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Обязателен для рекламных агентств, в остальных случаях не используется. Идентификатор
            клиента, у которого запрашиваются рекламные кампании.
        :param include_deleted: Флаг, задающий необходимость вывода архивных объявлений.   0 — выводить только
            активные кампании;  1 — выводить все кампании.
        :param campaign_ids: Фильтр выводимых рекламных кампаний.  Сериализованный JSON-массив, содержащий id
            кампаний. Выводиться будут только кампании, присутствующие в campaign_ids и являющиеся кампаниями
            указанного рекламного кабинета. Если параметр равен строке null, то выводиться будут все кампании.
        :param fields:

        :return: Возвращает массив объектов campaign, каждый из которых содержит следующие поля:   id —
            идентификатор кампании  type — тип кампании   normal — обычная кампания, в которой можно создавать любые
            объявления, кроме описанных в следующих пунктах;  vk_apps_managed — кампания, в которой можно
            рекламировать только администрируемые Вами приложения и у которой есть отдельный бюджет;  mobile_apps —
            кампания, в которой можно рекламировать только мобильные приложения;  promoted_posts — кампания, в
            которой можно рекламировать только записи в сообществе;  adaptive_ads — кампания, в которой можно
            рекламировать только объявления адаптивного формата.   name — название кампании  status — статус кампании
            0 — кампания остановлена  1 — кампания запущена  2 — кампания удалена   day_limit — дневной лимит
            кампании в рублях   0 — лимит не задан   all_limit — общий лимит кампании в рублях   0 — лимит не задан
            start_time — время запуска кампании в формате unixtime   0 — время не задано   stop_time — время
            остановки кампании в формате unixtime   0 — время не задан
        """

        params = locals()
        method_name = self._base_method + 'getCampaigns'
        return self._call(method_name, params)

    def getCategories(self, lang: str = None) -> dict:
        """
        Позволяет получить возможные тематики рекламных объявлений.

        :param lang: язык, на котором нужно вернуть результаты. Список поддерживаемых языков Вы можете найти на
            странице Запросы к API.

        :return: После успешного выполнения возвращает два массива объектов — v1 и v2, каждый из которых содержит
            объекты, описывающие тематики в следующем формате:   id — идентификатор тематики;  name — название
            тематики;  subcategories[subcategory] (если есть хотя бы один подраздел) — список подразделов. Массив
            объектов, каждый из которых содержит следующие поля:   id — идентификатор подраздела;  name — название
            подраздела.    Массив v1 включает устаревшие тематики. Актуальный список содержится в массиве v2
        """

        params = locals()
        method_name = self._base_method + 'getCategories'
        return self._call(method_name, params)

    def getClients(self, account_id: str = None) -> dict:
        """
        Возвращает список клиентов рекламного агентства.

        :param account_id: идентификатор рекламного кабинета.

        :return: Возвращает массив объектов client — клиентов агентства с номером account_id, каждый из которых
            содержит следующие поля:   id — идентификатор клиента;  name — название клиента;  day_limit — дневной
            лимит клиента в рублях;  all_limit — общий лимит клиента в рублях
        """

        params = locals()
        method_name = self._base_method + 'getClients'
        return self._call(method_name, params)

    def getDemographics(self, account_id: str = None, ids_type: str = None, ids: str = None, period: str = None,
                        date_from: str = None, date_to: str = None) -> dict:
        """
        Возвращает демографическую статистику по рекламным объявлениям или кампаниям.

        :param account_id: идентификатор рекламного кабинета.
        :param ids_type: Тип запрашиваемых объектов, которые перечислены в параметре ids:   ad — объявления;
            campaign — кампании.
        :param ids: Перечисленные через запятую id запрашиваемых объявлений или кампаний, в зависимости от того,
            что указано в параметре ids_type. Максимум 2000 объектов.
        :param period: способ группировки данных по датам:   day — статистика по дням;  month — статистика по
            месяцам;  overall — статистика за всё время.  Временные ограничения задаются параметрами date_from и
            date_to.
        :param date_from: Начальная дата выводимой статистики. Используется разный формат дат для разного
            значения параметра period:   day: YYYY-MM-DD, пример: 2011-09-27 - 27 сентября 2011   0 — день создания;
            month: YYYY-MM, пример: 2011-09 - сентябрь 2011   0 — месяц создания;   overall: 0
        :param date_to: Конечная дата выводимой статистики. Используется разный формат дат для разного значения
            параметра period:   day: YYYY-MM-DD, пример: 2011-09-27 - 27 сентября 2011   0 — текущий день;   month:
            YYYY-MM, пример: 2011-09 - сентябрь 2011   0 — текущий месяц;   overall: 0

        :return: Каждый запрашиваемый объект имеет следующие поля:   id — id объекта из параметра ids  type — тип
            объекта из параметра ids_type  stats — список структур описывающих статистику объекта за один временной
            период (конкретный временной период присутствует в списке, если по нему есть какая-то статистика)
            Структура в списке stats имеет следующие поля:   day (если period равен day) — день в формате YYYY-MM-DD
            month (если period равен month) — месяц в формате YYYY-MM  overall (если period равен overall) — 1  sex —
            список структур, описывающих статистику по полу  age — список структур, описывающих статистику по
            возрасту  sex_age — список структур, описывающих статистику по полу и возрасту  cities — список структур,
            описывающих статистику по городам  Структура в списках sex, age, sex_age, cities имеет следующие поля:
            impressions_rate — часть аудитории, просмотревшая объявление, от 0 до 1  clicks_rate — часть аудитории,
            кликнувшая по объявлению, от 0 до 1  value — значение демографического показателя, имеет разные возможные
            значения для разных показателей   sex (f — женщины, m — мужчины)  age — один из следующих промежутков:
            12-18, 18-21, 21-24, 24-27, 27-30, 30-35, 35-45, 45-100  sex_age — комбинация значений sex и age,
            разделённых точкой с запятой, пример: m;21-24  cities — id города или other для остальных городов   name
            — наглядное название значения указанного в value (только для городов
        """

        params = locals()
        method_name = self._base_method + 'getDemographics'
        return self._call(method_name, params)

    def getFloodStats(self, account_id: str = None) -> dict:
        """
        Возвращает информацию о текущем состоянии счетчика — количество оставшихся запусков методов и время до
        следующего обнуления счетчика в секундах.

        :param account_id: идентификатор рекламного кабинета.

        :return: Возвращает объект, содержащий следующие поля:   left — количество оставшихся методов;  refresh —
            время до следующего обновления в секундах
        """

        params = locals()
        method_name = self._base_method + 'getFloodStats'
        return self._call(method_name, params)

    def getLookalikeRequests(self, account_id: str = None, client_id: str = None, requests_ids: str = None,
                             offset: str = None, limit: str = None, sort_by: str = None) -> dict:
        """
        Возвращает список запросов на поиск похожей аудитории.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  идентификатор клиента, для которого возвращаются
            запросы.
        :param requests_ids: Список идентификаторов запрашиваемых запросов через запятую. Максимальное количество
            идентификаторов в списке – 200.  Если этот параметр пуст, возвращаться будут все запросы.
        :param offset: Смещение. Используется в связке с параметром limit.
        :param limit: Ограничение на количество возвращаемых запросов на поиск похожей аудитории. Используется в
            связке с параметром offset.   0 — вернуть только количество запросов в кабинете (у клиента в случае
            агентства).
        :param sort_by: Сортировка элементов. Возможные значения:   id – сортировать по возрастанию
            идентификаторов  update_time – сортировать по убыванию времени последнего обновления статуса

        :return: Если limit не равен 0, то возвращается объект с двумя полями:    count — количество запросов на
            поиск похожей аудитории в данном кабинете.  items — список объектов-запросов на поиск похожей аудитории
            запрошенного размера с запрошенным сдвигом.   При limit равном 0, возвращается только поле count.
            Описание запроса на поиск похожей аудитории – объект со следующими полями:   id — идентификатор запроса
            на поиск похожей аудитории. Является уникальным только в рамках конкретного кабинета (клиента в случае
            агентства).  create_time — timestamp даты создания запроса.  update_time — timestamp даты последнего
            обновления статуса запроса.  status — текущий статус запроса, может принимать следующие значения:
            search_in_progress, search_done, search_failed, save_in_progress, save_done, save_failed.
            scheduled_delete_time — timestamp даты запланированного удаления запроса.  source_type — тип источника
            исходной аудитории для поиска похожей аудитории. Может принимать только значение retargeting_group.
            source_retargeting_group_id — при source_type равном retargeting_group в данном поле указан идентификатор
            аудитории ретаргетинга с исходной аудиторией.  source_name — имя источника исходной аудитории. При
            source_type равном retargeting_group в данном поле указано название аудитории ретаргетинга на момент
            создания запроса.  audience_count — размер исходной аудитории.  save_audience_levels — Список доступных
            размеров аудитории для сохранения. Присутствует только после успешного поиска похожей аудитории. Поля:
            level — используется в качестве параметра level в ads.saveLookalikeRequestResult  audience_count — размер
            похожей аудитории в данной опции
        """

        params = locals()
        method_name = self._base_method + 'getLookalikeRequests'
        return self._call(method_name, params)

    def getOfficeUsers(self, account_id: str = None) -> dict:
        """
        Возвращает список администраторов и наблюдателей рекламного кабинета.

        :param account_id: идентификатор рекламного кабинета.

        :return: Возвращает массив объектов - описаний пользователей рекламного кабинета. Каждый объект содержит
            массив описаний прав доступа к конкретным клиентам. Описание содержит два поля: client_id — id клиента и
            role — строка admin, manager или reports. Для admin client_id не указывается
        """

        params = locals()
        method_name = self._base_method + 'getOfficeUsers'
        return self._call(method_name, params)

    def getPostsReach(self, account_id: str = None, ids_type: str = None, ids: str = None) -> dict:
        """
        Возвращает подробную статистику по охвату рекламных записей из объявлений и кампаний для продвижения записей
        сообщества.

        :param account_id: идентификатор рекламного кабинета.
        :param ids_type: Тип запрашиваемых объектов, которые перечислены в параметре ids:   ad — объявления;
            campaign — кампании.
        :param ids: Перечисленные через запятую id запрашиваемых объявлений или кампаний, в зависимости от того,
            что указано в параметре ids_type. Максимум 100 объектов.

        :return: Возвращает массив объектов, описывающих охват. Каждый объект содержит следующие поля:  id
            integerID объекта из параметра ids. reach_subscribers  integerохват подписчиков. reach_total
            integerсуммарный охват. links  integerпереходы по ссылке. to_group  integerпереходы в сообщество.
            join_group  integerвступления в сообщество. report  integerколичество жалоб на запись. hide
            integerколичество скрытий записи. unsubscribe  integerколичество отписавшихся участников.
            video_views_start*  integerколичество стартов просмотра видео. video_views_3s*  integerколичество
            досмотров видео до 3 секунд. video_views_25p*  integerколичество досмотров видео до 25 процентов.
            video_views_50p*  integerколичество досмотров видео до 50 процентов. video_views_75p*  integerколичество
            досмотров видео до 75 процентов. video_views_100p*  integerколичество досмотров видео до 100 процентов.
            * — поля с данными по статистике видео возвращаются только для объявлений или кампаний с видео, созданных
            после 26 января 2017 года
        """

        params = locals()
        method_name = self._base_method + 'getPostsReach'
        return self._call(method_name, params)

    def getRejectionReason(self, account_id: str = None, ad_id: str = None) -> dict:
        """
        Возвращает причину, по которой указанному объявлению было отказано в прохождении премодерации.

        :param account_id: идентификатор рекламного кабинета.
        :param ad_id: идентификатор рекламного объявления.

        :return: Возвращает объект, который может содержать поле comment, содержащее текстовый комментарий
            модератора, и/или массив rules, содержащий описание нарушенных объявлением правил. Ответ обязательно
            содержит хотя бы одно из полей comment или rules. Каждый элемент массива rules состоит из поля title
            (текстового пояснения) и массива paragraphs, каждый элемент которого содержит отдельный пункт правил.
            Элементы массива paragraphs могут содержать простую html-разметку
        """

        params = locals()
        method_name = self._base_method + 'getRejectionReason'
        return self._call(method_name, params)

    def getStatistics(self, account_id: str = None, ids_type: str = None, ids: str = None, period: str = None,
                      date_from: str = None, date_to: str = None, stats_fields: str = None) -> dict:
        """
        Возвращает статистику показателей эффективности по рекламным объявлениям, кампаниям, клиентам или всему
        кабинету.

        :param account_id: идентификатор рекламного кабинета.
        :param ids_type: Тип запрашиваемых объектов, которые перечислены в параметре ids:   ad — объявления;
            campaign — кампании;  client — клиенты;  office — кабинет.
        :param ids: Перечисленные через запятую id запрашиваемых объявлений, кампаний, клиентов или кабинета, в
            зависимости от того, что указано в параметре ids_type. Максимум 2000 объектов.
        :param period: Способ группировки данных по датам:   day — статистика по дням;  month — статистика по
            месяцам;  overall — статистика за всё время;  Временные ограничения задаются параметрами date_from и
            date_to.
        :param date_from: Начальная дата выводимой статистики. Используется разный формат дат для разного
            значения параметра period:   day: YYYY-MM-DD, пример: 2011-09-27 - 27 сентября 2011   0 — день создания;
            month: YYYY-MM, пример: 2011-09 - сентябрь 2011   0 — месяц создания;   overall: 0
        :param date_to: Конечная дата выводимой статистики. Используется разный формат дат для разного значения
            параметра period:   day: YYYY-MM-DD, пример: 2011-09-27 - 27 сентября 2011   0 — текущий день;   month:
            YYYY-MM, пример: 2011-09 - сентябрь 2011   0 — текущий месяц;   overall: 0
        :param stats_fields: Дополнительные статистики:   views_times — распределение количества показов на
            пользователя. Доступно для типов ad и campaign, содержащих только рекламные записи

        :return: Каждый запрашиваемый объект имеет следующие поля:   id — id объекта из параметра ids  type — тип
            объекта из параметра ids_type  stats — список структур описывающих статистику объекта за один временной
            период (конкретный временной период присутствует в списке, если по нему есть какая-то статистика)
            Структура в списке stats имеет следующие поля:     day (если period равен day) — день в формате YYYY-MM-
            DD  month (если period равен month) — день в формате YYYY-MM  overall (если period равен overall) — 1
            spent — потраченные средства  impressions — просмотры  clicks — клики  reach (если ids_type равен ad или
            campaign и period равен day или month) — охват  join_rate (если ids_type равен ad или campaign) —
            вступления в группу, событие, подписки на публичную страницу или установки приложения (только если в
            объявлении указана прямая ссылка на соответствующую страницу ВКонтакте
        """

        params = locals()
        method_name = self._base_method + 'getStatistics'
        return self._call(method_name, params)

    def getSuggestions(self, section: str = None, ids: str = None, q: str = None, country: str = None,
                       cities: str = None, lang: str = None) -> dict:
        """
        Возвращает набор подсказок для различных параметров таргетинга.

        :param section: Раздел, по которому запрашиваются подсказки.  Поддерживаются следующие значения:
            countries — страны;   q — необязательный параметр;   1 — возвращается полный список стран;  не задан —
            возвращается краткий список стран;    regions — регионы;   country — обязательный параметр;  q —
            обязательный параметр;   cities — города.   country — обязательный параметр;  q — необязательный
            параметр;   districts — районы   cities — обязательный параметр;   stations — станции метро   cities —
            обязательный параметр;   streets — улицы   cities — обязательный параметр;  q — обязательный параметр;
            schools — учебные заведения: школы, университеты, факультеты, кафедры   cities — обязательный параметр;
            q — обязательный параметр;   interest_categories_v2 — категории интересов;  interest_categories —
            устаревшие категории интересов;  positions — должности (профессии);   q — необязательный параметр;
            religions — религиозные взгляды;  user_devices — устройства;  user_os — операционные системы;
            user_browsers — интернет-браузеры.
        :param ids: ID объектов, разделённые запятыми. Служит для расшифровки ID, возвращаемых в методе
            ads.getAdsTargeting. Если задан этот параметр, то параметры q, country, cities не должны передаваться,
            таким образом отменяется их обязательность для конкретного раздела. Объекты возвращаются в том же
            порядке, в каком они были заданы в этом параметре.
        :param q: -фильтр запроса
        :param country: ID страны, в которой ищутся объекты.
        :param cities: ID городов, в которых ищутся объекты, разделенные запятыми.
        :param lang: Язык возвращаемых строковых значений. Поддерживаемые языки:   ru — русский;  ua —
            украинский;  en — английский.

        :return: Возвращает список объектов (подсказок), удовлетворяющих запросу.  Для разделов countries,
            positions, interest_categories, religions, user_devices, user_os, user_browsers ответ возвращается в виде
            массива объектов со следующими полями:   id — идентификатор объекта  name — название объекта   Для
            раздела regions ответ возвращается в виде массива объектов со следующими полями:   id — идентификатор
            региона  name — название региона  type (необязательное) — название типа региона (область, автономный
            округ, край)   Для разделов cities, districts, streets ответ возвращается в виде массива объектов со
            следующими полями:   id — идентификатор объекта  name — название объекта  parent — название города или
            страны, в котором находится объект   Для раздела schools ответ возвращается в виде массива объектов со
            следующими полями:   id — идентификатор учебного заведения  name — название учебного заведения  desc —
            полное название учебного заведения  type — тип учебного заведения   school — школа  university —
            университет  faculty — факультет  chair — кафедра   parent — название города, в котором находится учебное
            заведение   Для раздела interests ответ возвращается в виде массива строк
        """

        params = locals()
        method_name = self._base_method + 'getSuggestions'
        return self._call(method_name, params)

    def getTargetGroups(self, account_id: str = None, client_id: str = None, extended: str = None) -> dict:
        """
        Возвращает список аудиторий ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находятся
            аудитории.
        :param extended: если 1, в результатах будет указан код для размещения на сайте.  Устаревший параметр.
            Используется только для старых групп ретаргетинга, которые пополнялись без помощи пикселя. Для новых
            аудиторий его следует опускать.

        :return: Возвращает массив объектов, описывающих группы ретаргетинга. Каждый объект содержит следующие
            поля:   id (integer) — идентификатор аудитории;  name (string) — название аудитории ретаргетинга;
            last_updated (integer) — дата и время последнего пополнения аудитории в формате Unixtime;  is_audience
            (integer, 1) — 1, если группа является аудиторией (т.е.может быть пополнена при помощи пикселя);
            is_shared (integer, 1) — 1, если группа является копией (см. метод ads.shareTargetGroup);  audience_count
            (integer) — приблизительное количество пользователей, входящих в аудиторию;  lifetime (integer) —
            количество дней, через которое пользователи, добавляемые в аудиторию ретаргетинга, будут автоматически
            исключены из неё;  file_source (integer, 1) — признак пополнения аудитории через файл;  api_source
            (integer, 1) — признак пополнения аудитории через метод ads.importTargetContacts;  lookalike_source
            (integer, 1) — признак аудитории, полученной при помощи Look-a-Like.     pixel (string) — код для
            размещения на сайте рекламодателя. Возвращается, если параметр extended = 1 (только для старых групп).
            domain (string) — домен сайта, где размещен код учета пользователей (только для старых групп)
        """

        params = locals()
        method_name = self._base_method + 'getTargetGroups'
        return self._call(method_name, params)

    def getTargetPixels(self, account_id: str = None, client_id: str = None) -> dict:
        """
        Возвращает список пикселей ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находятся
            пиксели.

        :return: Возвращает массив объектов, каждый из которых содержит следующие поля:   target_pixel_id
            (integer) — идентификатор пикселя;  name (string) — название пикселя;  last_updated (integer) — дата и
            время последнего использования пикселя в формате Unixtime;  domain (string) — домен сайта, где размещен
            пиксель;  category_id (integer) — идентификатор категории сайта, где размещён пиксель (см. раздел
            interest_categories метода ads.getSuggestions);  pixel (string) — код для размещения на сайте
            рекламодателя
        """

        params = locals()
        method_name = self._base_method + 'getTargetPixels'
        return self._call(method_name, params)

    def getTargetingStats(self, account_id: str = None, client_id: str = None, criteria: str = None, ad_id: str = None,
                          ad_format: str = None, ad_platform: str = None, ad_platform_no_wall: str = None,
                          ad_platform_no_ad_network: str = None, link_url: str = None, link_domain: str = None) -> dict:
        """
        Возвращает размер целевой аудитории таргетинга, а также рекомендованные значения CPC и CPM.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: обязательный параметр для агентских кабинетов
        :param criteria: сериализованный JSON-объект, описывающий параметры таргетинга. Описание объекта criteria
            см. ниже. Игнорируется, если задан параметр ad_id.
        :param ad_id: идентификатор рекламного объявления, чьи параметры таргетинга требуется анализировать. Если
            задан этот параметр, criteria игнорируется.
        :param ad_format: формат объявления:   1 — изображение и текст;  2 — большое изображение;  3 —
            эксклюзивный формат;  4 — продвижение сообществ или приложений, квадратное изображение;  7 — специальный
            формат приложений;  8 — специальный формат сообществ;  9 — запись в сообществе;  10 — витрина приложений;
            11 — адаптивный формат.
        :param ad_platform: рекламные площадки, на которых будет показываться объявление:   (если ad_format равен
            1):   0 — ВКонтакте и сайты-партнёры;  1 — только ВКонтакте.   (если ad_format равен 9):   all — все
            площадки;  desktop — полная версия сайта;  mobile — мобильный сайт и приложения.   (если ad_format равен
            11):   all — все площадки;  desktop — полная версия сайта;  mobile — мобильный сайт и приложения.
        :param ad_platform_no_wall: Для ad_format = 9 и 11.  1 — не показывать объявление на стенах сообществ. По
            умолчанию: 0.
        :param ad_platform_no_ad_network: Для ad_format = 9 и 11.  1 — не показывать объявление в рекламной сети.
            По умолчанию: 0.
        :param link_url: ссылка на рекламируемый объект.
        :param link_domain: домен рекламируемого объекта.

        :return: Возвращает объект, описывающий целевую аудиторию и содержащий следующие поля:   audience_count
            (integer) — размер целевой аудитории  recommended_cpc (number) — рекомендованная цена для объявлений за
            клики, указана в рублях с копейками в дробной части. 0 — для форматов, для которых недоступна оплата за
            клики.  recommended_cpm (number)— рекомендованная цена для объявлений за показы, указана в рублях с
            копейками в дробной части.  recommended_cpc_50 (number) — рекомендованная цена для объявлений за клики, с
            прогнозом на достижение 50% охвата за первую неделю.  recommended_cpm_50 (number)— рекомендованная цена
            для объявлений за показы, с прогнозом на достижение 50% охвата за первую неделю.  recommended_cpc_70
            (number) — рекомендованная цена для объявлений за клики, с прогнозом на достижение 70% охвата за первую
            неделю.  recommended_cpm_70 (number)— рекомендованная цена для объявлений за показы, с расчетом на
            достижение 70% охвата за первую неделю.  recommended_cpc_90 (number) — рекомендованная цена для
            объявлений за клики, с прогнозом на достижение 90% охвата за первую неделю.  recommended_cpm_90 (number)—
            рекомендованная цена для объявлений за показы, с прогнозом на достижение 90% охвата за первую неделю.
            Обратите внимание, минимальный размер целевой аудитории — 100 человек. Если заданным критериям
            соответствует меньшее количество пользователей, размер аудитории будет считаться равным нулю
        """

        params = locals()
        method_name = self._base_method + 'getTargetingStats'
        return self._call(method_name, params)

    def getUploadURL(self, ad_format: str = None, icon: str = None) -> dict:
        """
        Возвращает URL-адрес для загрузки фотографии рекламного объявления.

        :param ad_format: формат объявления:   1 — изображение и текст;  2 — большое изображение;  3 —
            эксклюзивный формат;  4 — продвижение сообществ или приложений, квадратное изображение;  5 — приложение в
            новостной ленте (устаревший);  6 — мобильное приложение;  11 — адаптивный формат.   Для формата
            объявления «запись в сообществе» этот метод не используется, т.к. фотографии являются частью записи со
            стены сообщества. См. методы ads.createAds и wall.postAdsStealth
        :param icon: 1 — получить URL для загрузки логотипа, а не основного изображения. Используется только для
            ad_format = 11.

        :return: Возвращает url-адрес для загрузки изображения
        """

        params = locals()
        method_name = self._base_method + 'getUploadURL'
        return self._call(method_name, params)

    def getVideoUploadURL(self) -> dict:
        """
        Возвращает URL-адрес для загрузки видеозаписи рекламного объявления.

        :return: Возвращает url-адрес для загрузки видеоролика
        """

        params = locals()
        method_name = self._base_method + 'getVideoUploadURL'
        return self._call(method_name, params)

    def importTargetContacts(self, account_id: str = None, client_id: str = None, target_group_id: str = None,
                             contacts: str = None) -> dict:
        """
        Импортирует список контактов рекламодателя для учета зарегистрированных во ВКонтакте пользователей в аудитории
        ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находится
            аудитория.
        :param target_group_id: идентификатор аудитории таргетинга.
        :param contacts: список телефонов, email адресов или идентификаторов пользователей, указанных через
            запятую. Также принимаются их MD5-хеши.

        :return: Возвращает количество обработанных контактов
        """

        params = locals()
        method_name = self._base_method + 'importTargetContacts'
        return self._call(method_name, params)

    def removeOfficeUsers(self, account_id: str = None, ids: str = None) -> dict:
        """
        Удаляет администраторов и/или наблюдателей из рекламного кабинета.

        :param account_id: идентификатор рекламного кабинета.
        :param ids: сериализованный JSON-массив, содержащий id удаляемых администраторов.

        :return: Возвращает массив значений - ответов на каждый запрос в массиве data. Соответствующее значение в
            выходном массиве равно true, если администратор успешно удален, и false в другом случае
        """

        params = locals()
        method_name = self._base_method + 'removeOfficeUsers'
        return self._call(method_name, params)

    def removeTargetContacts(self, account_id: str = None, client_id: str = None, target_group_id: str = None,
                             contacts: str = None) -> dict:
        """
        Принимает запрос на исключение контактов рекламодателя из аудитории ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находится
            аудитория.
        :param target_group_id: идентификатор аудитории таргетинга.
        :param contacts: список телефонов, email адресов или идентификаторов пользователей, указанных через
            запятую. Также принимаются их MD5-хеши.

        :return: Возвращает 1 в случае успешного принятия заявки на исключение аудитории
        """

        params = locals()
        method_name = self._base_method + 'removeTargetContacts'
        return self._call(method_name, params)

    def saveLookalikeRequestResult(self, account_id: str = None, client_id: str = None, request_id: str = None,
                                   level: str = None) -> dict:
        """
        Сохраняет результат поиска похожей аудитории.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  идентификатор клиента, для которого будут сохраняться
            аудитория.
        :param request_id: Идентификатор запроса на поиск похожей аудитории. Получить список всех запросов на
            поиск похожей аудитории для данного кабинета можно с помощью ads.getLookalikeRequests
        :param level: Уровень конкретного размера похожей аудитории для сохранения. Получить список всех
            доступных размеров аудиторий можно с помощью ads.getLookalikeRequests.

        :return: Возвращает объект с полями:    retargeting_group_id – идентификатор группы ретаргетинга, в
            которую будет сохранена запрошенная похожая аудитория.  audience_count – размер запрошенной похожей
            аудитории
        """

        params = locals()
        method_name = self._base_method + 'saveLookalikeRequestResult'
        return self._call(method_name, params)

    def shareTargetGroup(self, account_id: str = None, client_id: str = None, target_group_id: str = None,
                         share_with_client_id: str = None) -> dict:
        """
        Предоставляет доступ к аудитории ретаргетинга другому рекламному кабинету. В результате выполнения метода
        возвращается идентификатор аудитории для указанного кабинета.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находится
            исходная аудитория.
        :param target_group_id: идентификатор исходной аудитории.
        :param share_with_client_id: id клиента, рекламному кабинету которого необходимо предоставить доступ к
            аудитории.

        :return: Возвращает объект со следующими полями:   id — идентификатор аудитории
        """

        params = locals()
        method_name = self._base_method + 'shareTargetGroup'
        return self._call(method_name, params)

    def updateAds(self, account_id: str = None, data: str = None) -> dict:
        """
        Редактирует рекламные объявления.

        :param account_id: идентификатор рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих изменения в объявлениях. Описание объектов
            ad_edit_specification см. ниже.  Максимальное допустимое количество объявлений,  редактируемых с помощью
            одного запроса — 5. Если нужно больше, то можно использовать execute.

        :return: Возвращает массив ответов на каждый запрос в массиве data. Соответствующий объект в выходном
            массиве содержит идентификатор изменяемого объявления и, в случае возникновения ошибки, поля error_code и
            error_desc
        """

        params = locals()
        method_name = self._base_method + 'updateAds'
        return self._call(method_name, params)

    def updateCampaigns(self, account_id: str = None, data: str = None) -> dict:
        """
        Редактирует рекламные кампании.

        :param account_id: идентификатор рекламного кабинета.
        :param data: Сериализованный JSON-массив объектов, описывающих изменения в кампаниях. Описание объектов
            campaign_mod_specification см. ниже.

        :return: Возвращает массив ответов на каждый запрос в массиве data. Соответствующий объект в выходном
            массиве содержит идентификатор изменяемого клиента и, в случае возникновения ошибки, поля error_code и
            error_desc
        """

        params = locals()
        method_name = self._base_method + 'updateCampaigns'
        return self._call(method_name, params)

    def updateClients(self, account_id: str = None, data: str = None) -> dict:
        """
        Редактирует клиентов рекламного агентства.

        :param account_id: идентификатор рекламного кабинета.
        :param data: сериализованный JSON-массив объектов, описывающих изменения в клиентах. Описание объектов
            client_mod_specification см. ниже.

        :return: Возвращает массив ответов на каждый запрос в массиве data. Соответствующий объект в выходном
            массиве содержит id изменяемого клиента и, в случае возникновения ошибки, поля error_code и error_desc
        """

        params = locals()
        method_name = self._base_method + 'updateClients'
        return self._call(method_name, params)

    def updateTargetGroup(self, account_id: str = None, client_id: str = None, target_group_id: str = None,
                          name: str = None, domain: str = None, lifetime: str = None, target_pixel_id: str = None,
                          target_pixel_rules: str = None) -> dict:
        """
        Редактирует аудиторию ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого будет
            редактироваться аудитория.
        :param target_group_id: идентификатор аудитории.
        :param name: новое название аудитории ретаргетинга — строка до 64 символов.
        :param domain: Домен сайта, на котором будет размещен код учета пользователей.  Устаревший параметр.
            Используется только для старых групп ретаргетинга, которые пополнялись без помощи пикселя. Для новых
            аудиторий его следует опускать, иначе будет возвращена ошибка.
        :param lifetime: Количество дней, через которое пользователи, добавляемые в аудиторию, будут
            автоматически исключены из нее.
        :param target_pixel_id: Передайте в этом параметре идентификатор пикселя, если требуется собирать
            аудиторию с веб-сайта.
        :param target_pixel_rules: Закодированный в JSON массив правил, в соответствии с которыми будет
            пополняться аудитория из пикселя. Подробнее см. документацию метода ads.createTargetGroup.

        :return: В случае успеха метод возвратит 1
        """

        params = locals()
        method_name = self._base_method + 'updateTargetGroup'
        return self._call(method_name, params)

    def updateTargetPixel(self, account_id: str = None, client_id: str = None, target_pixel_id: str = None,
                          name: str = None, domain: str = None, category_id: str = None) -> dict:
        """
        Редактирует пиксель ретаргетинга.

        :param account_id: идентификатор рекламного кабинета.
        :param client_id: Только для рекламных агентств.  id клиента, в рекламном кабинете которого находится
            пиксель.
        :param target_pixel_id: идентификатор пикселя.
        :param name: новое название пикселя — строка до 64 символов.
        :param domain: новый домен сайта, на котором будет размещен код пикселя.
        :param category_id: новый идентификатор категории сайта, на котором будет размещен пиксель. Для получения
            списка возможных идентификаторов можно использовать метод ads.getSuggestions (раздел
            interest_categories).

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'updateTargetPixel'
        return self._call(method_name, params)




import requests
from api_methods import *


class VK:
    def __init__(self, access_token, v=5.101, bot=False):
        session = requests.session()

        if bot:
            calls_per_second = 25
        else:
            calls_per_second = 3

        self.account = Account(access_token, v, session, calls_per_second)
        self.ads = Ads(access_token, v, session, calls_per_second)
        self.appWidgets = AppWidgets(access_token, v, session, calls_per_second)
        # self.apps = Apps(access_token, v, session, calls_per_second)
        self.auth = Auth(access_token, v, session, calls_per_second)
        self.board = Board(access_token, v, session, calls_per_second)
        self.database = Database(access_token, v, session, calls_per_second)
        self.docs = Docs(access_token, v, session, calls_per_second)
        # self.downloadedGames = DownloadedGames(access_token, v, session, calls_per_second)
        self.docs = Docs(access_token, v, session, calls_per_second)
        self.execute = Execute(access_token, v, session, calls_per_second)
        self.fave = Fave(access_token, v, session, calls_per_second)
        self.friends = Friends(access_token, v, session, calls_per_second)
        self.gifts = Gifts(access_token, v, session, calls_per_second)
        self.groups = Groups(access_token, v, session, calls_per_second)
        self.leadForms = LeadForms(access_token, v, session, calls_per_second)
        self.leads = Leads(access_token, v, session, calls_per_second)
        self.likes = Likes(access_token, v, session, calls_per_second)
        self.market = Market(access_token, v, session, calls_per_second)
        self.messages = Messages(access_token, v, session, calls_per_second)
        self.newsfeed = Newsfeed(access_token, v, session, calls_per_second)
        self.notes = Notes(access_token, v, session, calls_per_second)
        self.notifications = Notifications(access_token, v, session, calls_per_second)
        self.orders = Orders(access_token, v, session, calls_per_second)
        self.pages = Pages(access_token, v, session, calls_per_second)
        self.photos = Photos(access_token, v, session, calls_per_second)
        # self.podcasts = Podcasts(access_token, v, session, calls_per_second)
        self.polls = Polls(access_token, v, session, calls_per_second)
        self.prettyCards = PrettyCards(access_token, v, session, calls_per_second)
        self.search = Search(access_token, v, session, calls_per_second)
        self.secure = Secure(access_token, v, session, calls_per_second)
        self.stats = Stats(access_token, v, session, calls_per_second)
        self.status = Status(access_token, v, session, calls_per_second)
        self.storage = Storage(access_token, v, session, calls_per_second)
        self.stories = Stories(access_token, v, session, calls_per_second)
        self.streaming = Streaming(access_token, v, session, calls_per_second)
        self.users = Users(access_token, v, session, calls_per_second)
        self.utils = Utils(access_token, v, session, calls_per_second)
        self.video = Video(access_token, v, session, calls_per_second)
        self.wall = Wall(access_token, v, session, calls_per_second)
        self.widgets = Widgets(access_token, v, session, calls_per_second)



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

with open('readme.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name="easy_vk",
    version="0.0.8",
    author="Phinnik",
    author_email="elecdron@gmail.com",
    description="Обертка для VK api",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Phinnik/easy_vk",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=['requests']
)


from ApiMethod import ApiMethod


class Wall(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Wall, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'wall.'

    def checkCopyrightLink(self, link: str = None) -> dict:
        """
        Проверяет ссылку для указания источника.

        :param link: ссылка на источник. Поддерживаются внешние и внутренние ссылки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'checkCopyrightLink'
        return self._call(method_name, params)

    def closeComments(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Выключает комментирование записи

        :param owner_id:
        :param post_id:

        :return: Возвращает 1 в случае успех
        """

        params = locals()
        method_name = self._base_method + 'closeComments'
        return self._call(method_name, params)

    def createComment(self, owner_id: str = None, post_id: str = None, from_group: str = None, message: str = None,
                      reply_to_comment: str = None, attachments: str = None, sticker_id: str = None,
                      guid: str = None) -> dict:
        """
        Добавляет комментарий к записи на стене.

        :param owner_id: идентификатор пользователя или сообщества, на чьей стене находится запись, к которой
            необходимо добавить комментарий. Обратите внимание, идентификатор сообщества в параметре owner_id
            необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору сообщества
            ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.
        :param from_group: идентификатор сообщества, от имени которого публикуется комментарий. По умолчанию: 0.
        :param message: текст комментария. Обязательный параметр, если не передан параметр attachments.
        :param reply_to_comment: идентификатор комментария, в ответ на который должен быть добавлен новый
            комментарий.
        :param attachments: список объектов, приложенных к комментарию и разделённых символом ",". Поле
            attachments представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id> <type> —
            тип медиа-вложения: photo — фотография  video — видеозапись  audio — аудиозапись  doc — документ
            <owner_id> — идентификатор владельца медиа-вложения  <media_id> — идентификатор медиа-вложения.
            Например: photo100172_166443618,photo66748_265827614 Параметр является обязательным, если не задан
            параметр message.
        :param sticker_id: идентификатор стикера.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинакового
            комментария.

        :return: После успешного выполнения возвращает идентификатор добавленного комментария в поле comment_id
            (integer) и массив идентификаторов родительских комментариев в поле parent_stack (array)
        """

        params = locals()
        method_name = self._base_method + 'createComment'
        return self._call(method_name, params)

    def delete(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Удаляет запись со стены.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится запись. Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def deleteComment(self, owner_id: str = None, comment_id: str = None) -> dict:
        """
        Удаляет комментарий к записи на стене.

        :param owner_id: идентификатор пользователя, на чьей стене находится комментарий к записи. Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteComment'
        return self._call(method_name, params)

    def edit(self, owner_id: str = None, post_id: str = None, friends_only: str = None, message: str = None,
             attachments: str = None, services: str = None, signed: str = None, publish_date: str = None,
             lat: str = None, long: str = None, place_id: str = None, mark_as_ads: str = None,
             close_comments: str = None, poster_bkg_id: str = None, poster_bkg_owner_id: str = None,
             poster_bkg_access_hash: str = None, copyright: str = None) -> dict:
        """
        Редактирует запись на стене.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится запись. Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.
        :param friends_only: 1 — запись будет доступна только друзьям, 0 — всем пользователям.  Параметр
            учитывается только при редактировании отложенной записи.
        :param message: текст сообщения (является обязательным, если не задан параметр attachments)
        :param attachments: список объектов, приложенных к записи и разделённых символом ",". Поле attachments
            представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id>  <type> — тип медиа-
            приложения:    photo — фотография  video — видеозапись  audio — аудиозапись  doc — документ  graffiti —
            граффити  page — wiki-страница  note — заметка  poll — опрос  album — альбом.   <owner_id> —
            идентификатор владельца медиа-приложения; <media_id> — идентификатор медиа-приложения.  Например:
            photo100172_166443618,photo66748_265827614  Также в поле attachments может быть указана ссылка на внешнюю
            страницу, которую Вы хотите разместить в статусе, например: photo66748_265827614,http://habrahabr.ru  При
            попытке приложить больше одной ссылки будет возвращена ошибка.   Параметр является обязательным, если не
            задан параметр message.
        :param services: список сервисов или сайтов, на которые необходимо экспортировать запись, в случае если
            пользователь настроил соответствующую опцию. Например, twitter, facebook.  Параметр учитывается только
            при редактировании отложенной записи.
        :param signed: 1 — у записи, размещенной от имени сообщества будет добавлена подпись (имя пользователя,
            разместившего запись), 0 — подписи добавлено не будет.  Параметр учитывается только при редактировании
            записи на стене сообщества, опубликованной от имени группы.
        :param publish_date: дата публикации записи в формате unixtime. Если параметр не указан, отложенная
            запись будет опубликована.  Параметр учитывается только при редактировании отложенной записи.
        :param lat: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param long: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param place_id: идентификатор места, в котором отмечен пользователь.
        :param mark_as_ads: 1 — у записи, размещенной от имени сообщества, будет добавлена метка "это реклама", 0
            — метки добавлено не будет/снять установленную метку. Метка может быть снята в течение пяти минут после
            её установки. В сутки может быть опубликовано не более пяти рекламных записей, из которых не более трёх —
            вне Биржи ВКонтакте.
        :param close_comments: 1 — комментарии к записи отключены.  0 — комментарии к записи включены.
        :param poster_bkg_id:
        :param poster_bkg_owner_id:
        :param poster_bkg_access_hash:
        :param copyright: источник материала. Поддерживаются внешние и внутренние ссылки.

        :return: После успешного выполнения возвращает post_id — идентификатор отредактированного поста
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def editAdsStealth(self, owner_id: str = None, post_id: str = None, message: str = None, attachments: str = None,
                       signed: str = None, lat: str = None, long: str = None, place_id: str = None,
                       link_button: str = None, link_title: str = None, link_image: str = None,
                       link_video: str = None) -> dict:
        """
        Позволяет отредактировать скрытую запись.

        :param owner_id: идентификатор владельца стены (идентификатор сообщества нужно указывать со знаком
            «минус»).
        :param post_id: идентификатор записи.
        :param message: текст записи.
        :param attachments: список объектов, приложенных к записи и разделённых символом ",". Поле attachments
            представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id>   <type> — тип медиа-
            приложения:   photo — фотография;  video — видеозапись ;  audio — аудиозапись;  doc — документ;  page —
            wiki-страница;  note — заметка;  poll — опрос;  album — альбом;  market — товар;  market_album — подборка
            товаров.   <owner_id> — идентификатор владельца медиа-приложения (обратите внимание, если объект
            находится в сообществе, этот параметр должен быть отрицательным).  <media_id> — идентификатор медиа-
            приложения.   Например: photo100172_166443618,photo-1_265827614  Также в поле attachments может быть
            указана ссылка на внешнюю страницу, которую Вы хотите разместить в записи, например:
            photo66748_265827614,http://habrahabr.ru  В качестве ссылки может быть использован телефонный номер в
            формате tel:+71234567890  При попытке приложить больше одной ссылки будет возвращена ошибка.   Параметр
            является обязательным, если не задан параметр message.
        :param signed: 1 — у записи, размещенной от имени сообщества, будет добавлена подпись (имя пользователя,
            разместившего запись), 0 — без подписи.
        :param lat: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param long: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param place_id: идентификатор места.
        :param link_button: идентификатор кнопки, которую необходимо добавить к сниппету для ссылки. Подробнее
            см. документацию метода wall.postAdsStealth.
        :param link_title: заголовок, который должен быть использован для сниппета. Если не указан, будет
            автоматически получен с целевой ссылки. Обязательно указывать в случае, если ссылка является номером
            телефона.
        :param link_image: ссылка на изображение, которое должно быть использовано для сниппета. Минимальное
            разрешение: 537x240. Если не указана, будет автоматически загружена с целевой ссылки. Обязательно
            указывать в случае, если ссылка является номером телефона. Одновременно может быть указан либо параметр
            link_image, либо параметр link_video.
        :param link_video: идентификатор видео в формате "<owner_id>_<media_id>". Одновременно может быть указан
            либо параметр link_image, либо параметр link_video. Кроме того, параметр link_video может быть указан
            только вместе с параметрами link_button, link_title.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editAdsStealth'
        return self._call(method_name, params)

    def editComment(self, owner_id: str = None, comment_id: str = None, message: str = None,
                    attachments: str = None) -> dict:
        """
        Редактирует комментарий на стене.

        :param owner_id: идентификатор владельца стены. Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария, который необходимо отредактировать.
        :param message: новый текст комментария. Обязательный параметр, если не передан параметр attachments.
        :param attachments: новые вложения к комментарию. Список объектов, приложенных к комментарию и
            разделённых символом ",". Поле attachments представляется в формате:
            <type><owner_id>_<media_id>,<type><owner_id>_<media_id> <type> — тип медиа-вложения: photo — фотография
            video — видеозапись  audio — аудиозапись  doc — документ <owner_id> — идентификатор владельца медиа-
            вложения  <media_id> — идентификатор медиа-вложения.   Например:
            photo100172_166443618,photo66748_265827614 Параметр является обязательным, если не задан параметр
            message.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editComment'
        return self._call(method_name, params)

    def get(self, owner_id: str = None, domain: str = None, offset: str = None, count: str = None, filter: str = None,
            extended: str = None, fields: str = None) -> dict:
        """
        Возвращает список записей со стены пользователя или сообщества.

        :param owner_id: идентификатор пользователя или сообщества, со стены которого необходимо получить записи
            (по умолчанию — текущий пользователь). Обратите внимание, идентификатор сообщества в параметре owner_id
            необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору сообщества
            ВКонтакте API (club1)
        :param domain: короткий адрес пользователя или сообщества.
        :param offset: смещение, необходимое для выборки определенного подмножества записей.
        :param count: количество записей, которое необходимо получить. Максимальное значение: 100.
        :param filter: определяет, какие типы записей на стене необходимо получить. Возможные значения:
            suggests — предложенные записи на стене сообщества (доступно только при вызове с передачей access_token);
            postponed — отложенные записи (доступно только при вызове с передачей access_token);  owner — записи
            владельца стены;  others — записи не от владельца стены;  all — все записи на стене (owner + others).  По
            умолчанию: all.
        :param extended: 1 — в ответе будут возвращены дополнительные поля profiles и groups, содержащие
            информацию о пользователях и сообществах. По умолчанию: 0.
        :param fields: список дополнительных полей для профилей и сообществ, которые необходимо вернуть.
            Обратите внимание, этот параметр учитывается только при extended=1.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов записей на стене в поле items.  Если был задан параметр extended=1, возвращает число результатов
            в поле count, отдельно массив объектов записей на стене в поле items, пользователей в поле profiles и
            сообществ в поле groups
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getById(self, posts: str = None, extended: str = None, copy_history_depth: str = None,
                fields: str = None) -> dict:
        """
        Возвращает список записей со стен пользователей или сообществ по их идентификаторам.

        :param posts: перечисленные через запятую идентификаторы, которые представляют собой идущие через знак
            подчеркивания id владельцев стен и id самих записей на стене. Максимум 100 идентификаторов. Пример
            значения posts: 93388_21539,93388_20904,-1_340364
        :param extended: 1 — в ответе будут возвращены дополнительные поля profiles и groups, содержащие
            информацию о пользователях и сообществах. По умолчанию: 0.
        :param copy_history_depth: определяет размер массива copy_history, возвращаемого в ответе, если запись
            является репостом записи с другой стены.  Например, copy_history_depth=1 — copy_history будет содержать
            один элемент с информацией о записи, прямым репостом которой является текущая.  copy_history_depth=2 —
            copy_history будет содержать два элемента, добавляется информация о записи, репостом которой является
            первый элемент, и так далее (при условии, что иерархия репостов требуемой глубины для текущей записи
            существует).
        :param fields: список дополнительных полей для профилей и групп, которые необходимо вернуть. См. описание
            полей объекта user и описание полей объекта group.  Обратите внимание, этот параметр учитывается только
            при extended=1.

        :return: После успешного выполнения возвращает объект, содержащий массив объектов записей на стене.  Если
            был задан параметр extended=1, возвращает отдельно массив объектов записей на стене в поле items,
            пользователей в поле profiles и сообществ в поле groups
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getComment(self, owner_id: str = None, comment_id: str = None, extended: str = None,
                   fields: str = None) -> dict:
        """
        Получает информацию о комментарии на стене.

        :param owner_id: идентификатор владельца стены (для сообществ — со знаком «минус»).
        :param comment_id: идентификатор комментария.
        :param extended: 1 — в ответе будут возвращены дополнительные поля profiles и groups, содержащие
            информацию о пользователях и сообществах. По умолчанию: 0.
        :param fields: список дополнительных полей для профилей и сообществ, которые необходимо вернуть.
            Обратите внимание, этот параметр учитывается только при extended=1.

        :return: Возвращает объект комментария на стене. Если был передан параметр extended = 1, дополнительно
            возвращает поля groups (array) и profiles (array), содержащие информацию о пользователях и сообществах
        """

        params = locals()
        method_name = self._base_method + 'getComment'
        return self._call(method_name, params)

    def getComments(self, owner_id: str = None, post_id: str = None, need_likes: str = None,
                    start_comment_id: str = None, offset: str = None, count: str = None, sort: str = None,
                    preview_length: str = None, extended: str = None, fields: str = None, comment_id: str = None,
                    thread_items_count: str = None) -> dict:
        """
        Возвращает список комментариев к записи на стене.

        :param owner_id: идентификатор владельца страницы (пользователь или сообщество). Обратите внимание,
            идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1
            соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.
        :param need_likes: 1 — возвращать информацию о лайках.
        :param start_comment_id: идентификатор комментария, начиная с которого нужно вернуть список (подробности
            см. ниже).
        :param offset: сдвиг, необходимый для получения конкретной выборки результатов.
        :param count: число комментариев, которые необходимо получить. По умолчанию: 10, максимальное значение:
            100.
        :param sort: порядок сортировки комментариев. Возможные значения:   asc — от старых к новым;  desc — от
            новых к старым.
        :param preview_length: количество символов, по которому нужно обрезать текст комментария. Укажите 0, если
            Вы не хотите обрезать текст.
        :param extended: 1 — в ответе будут возвращены дополнительные поля profiles и groups, содержащие
            информацию о пользователях и сообществах. По умолчанию: 0.
        :param fields: список дополнительных полей для профилей и сообществ, которые необходимо вернуть.
            Обратите внимание, этот параметр учитывается только при extended=1.
        :param comment_id: идентификатор комментария, ветку которого нужно получить.
        :param thread_items_count: максимальное число элементов в поле thread.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов комментариев в поле items, а также поля:   current_level_count (integer) — количество
            комментариев в ветке.  can_post (boolean) – может ли текущий пользователь оставлять комментарии в этой
            ветке.  show_reply_button (boolean) – нужно ли отображать кнопку «ответить» в ветке.  groups_can_post
            (boolean) – могут ли сообщества оставлять комментарии в ветке.   Если был задан параметр need_likes=1, у
            объектов комментариев возвращается дополнительное поле likes, содержащее объект с полями:   count — число
            пользователей, которым понравился комментарий;  user_likes — наличие отметки «Мне нравится» от текущего
            пользователя  (1 — есть, 0 — нет);  can_like — информация о том, может ли текущий пользователь поставить
            отметку «Мне нравится»  (1 — может, 0 — не может).   Если был передан параметр start_comment_id, будет
            также возвращено поле real_offset – итоговое смещение данного подмножества комментариев (оно может быть
            отрицательным, если был указан отрицательный offset).  Если был задан параметр extended=1, возвращает
            число результатов в поле count, отдельно массив объектов комментариев в поле items, пользователей в поле
            profiles и сообществ в поле groups
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def getReposts(self, owner_id: str = None, post_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Позволяет получать список репостов заданной записи.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится запись. Если
            параметр не задан, то он считается равным идентификатору текущего пользователя. Обратите внимание,
            идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1
            соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.
        :param offset: смещение, необходимое для выборки определенного подмножества записей.
        :param count: количество записей, которое необходимо получить.

        :return: После успешного выполнения возвращает объект, содержащий поля:   items — содержит массив
            записей-репостов;  profiles — содержит объекты пользователей с дополнительными полями sex, online, photo,
            photo_medium_rec, screen_name;  groups — содержит информацию о сообществах
        """

        params = locals()
        method_name = self._base_method + 'getReposts'
        return self._call(method_name, params)

    def openComments(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Включает комментирование записи

        :param owner_id:
        :param post_id:

        :return: Возвращает 1 в случае успех
        """

        params = locals()
        method_name = self._base_method + 'openComments'
        return self._call(method_name, params)

    def pin(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Закрепляет запись на стене (запись будет отображаться выше остальных).

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится запись. Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'pin'
        return self._call(method_name, params)

    def post(self, owner_id: str = None, friends_only: str = None, from_group: str = None, message: str = None,
             attachments: str = None, services: str = None, signed: str = None, publish_date: str = None,
             lat: str = None, long: str = None, place_id: str = None, post_id: str = None, guid: str = None,
             mark_as_ads: str = None, close_comments: str = None, mute_notifications: str = None,
             copyright: str = None) -> dict:
        """
        Позволяет создать запись на стене, предложить запись на стене публичной страницы, опубликовать существующую
        отложенную запись.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого должна быть опубликована
            запись. Обратите внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком
            "-" — например, owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param friends_only: 1 — запись будет доступна только друзьям, 0 — всем пользователям. По умолчанию
            публикуемые записи доступны всем пользователям.
        :param from_group: данный параметр учитывается, если owner_id < 0 (запись публикуется на стене группы). 1
            — запись будет опубликована от имени группы, 0 — запись будет опубликована от имени пользователя (по
            умолчанию).
        :param message: текст сообщения (является обязательным, если не задан параметр attachments)
        :param attachments: список объектов, приложенных к записи и разделённых символом ",". Поле attachments
            представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id>   <type> — тип медиа-
            приложения:   photo — фотография;  video — видеозапись ;  audio — аудиозапись;  doc — документ;  page —
            wiki-страница;  note — заметка;  poll — опрос;  album — альбом;  market — товар;  market_album — подборка
            товаров;  audio_playlist — плейлист с аудио.   <owner_id> — идентификатор владельца медиа-приложения
            (обратите внимание, если объект находится в сообществе, этот параметр должен быть отрицательным).
            <media_id> — идентификатор медиа-приложения.   Например: photo100172_166443618,photo-1_265827614  Также в
            поле attachments может быть указана ссылка на внешнюю страницу, которую Вы хотите разместить в записи,
            например: photo66748_265827614,http://habrahabr.ru  При попытке приложить больше одной ссылки будет
            возвращена ошибка.   Параметр является обязательным, если не задан параметр message.
        :param services: список сервисов или сайтов, на которые необходимо экспортировать запись, в случае если
            пользователь настроил соответствующую опцию. Например, twitter, facebook.
        :param signed: 1 — у записи, размещенной от имени сообщества, будет добавлена подпись (имя пользователя,
            разместившего запись), 0 — подписи добавлено не будет. Параметр учитывается только при публикации на
            стене сообщества и указании параметра from_group. По умолчанию подпись не добавляется.
        :param publish_date: дата публикации записи в формате unixtime. Если параметр указан, публикация записи
            будет отложена до указанного времени.
        :param lat: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param long: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param place_id: идентификатор места, в котором отмечен пользователь.
        :param post_id: идентификатор записи, которую необходимо опубликовать. Данный параметр используется для
            публикации отложенных записей и предложенных новостей.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинаковой
            записи. Действует в течение одного часа.
        :param mark_as_ads: 1 — у записи, размещенной от имени сообщества, будет добавлена метка "это реклама", 0
            — метки добавлено не будет. В сутки может быть опубликовано не более пяти рекламных записей, из которых
            не более трёх — вне Биржи ВКонтакте.
        :param close_comments: 1 — комментарии к записи отключены.  0 — комментарии к записи включены.
        :param mute_notifications: 1 — уведомления к записи отключены.  0 — уведомления к записи включены.
        :param copyright: источник материала. Поддерживаются внешние и внутренние ссылки.

        :return: После успешного выполнения возвращает идентификатор созданной записи (post_id)
        """

        params = locals()
        method_name = self._base_method + 'post'
        return self._call(method_name, params)

    def postAdsStealth(self, owner_id: str = None, message: str = None, attachments: str = None, signed: str = None,
                       lat: str = None, long: str = None, place_id: str = None, guid: str = None,
                       link_button: str = None, link_title: str = None, link_image: str = None,
                       link_video: str = None) -> dict:
        """
        Позволяет создать скрытую запись, которая не попадает на стену сообщества и в дальнейшем может быть
        использована для создания рекламного объявления типа "Запись в сообществе".

        :param owner_id: идентификатор владельца стены (идентификатор сообщества нужно указывать со знаком
            «минус»).
        :param message: текст записи.
        :param attachments: список объектов, приложенных к записи и разделённых символом ",".   В поле может быть
            указана ссылка на страницу, которую Вы хотите разместить в записи, например:
            photo66748_265827614,http://habrahabr.ru   Либо поле attachments представляется в формате:
            <type><owner_id>_<media_id>,<type><owner_id>_<media_id>   <type> — тип медиа-приложения:   photo —
            фотография;  video — видеозапись;  audio — аудиозапись;  doc — документ;  page — wiki-страница;  note —
            заметка;  poll — опрос;  album — альбом;  market — товар;  market_album — подборка товаров,  pretty_card
            — карточка карусели.   <owner_id> — идентификатор владельца медиа-приложения (обратите внимание, если
            объект находится в сообществе, этот параметр должен быть отрицательным).  <media_id> — идентификатор
            медиа-приложения.   Например: photo100172_166443618,photo-1_265827614  В качестве ссылки может быть
            использован телефонный номер в формате tel:+71234567890  При попытке приложить больше одной ссылки будет
            возвращена ошибка.   Параметр является обязательным, если не задан параметр message.
        :param signed: 1 — у записи, размещенной от имени сообщества, будет добавлена подпись (имя пользователя,
            разместившего запись), 0 — без подписи.
        :param lat: географическая широта отметки, заданная в градусах (от -90 до 90).
        :param long: географическая долгота отметки, заданная в градусах (от -180 до 180).
        :param place_id: идентификатор места.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинаковой
            записи.
        :param link_button: идентификатор кнопки, которую необходимо добавить к сниппету для ссылки.  link_button
            Текст Действие Тип ссылок auto (автовыбор) (автовыбор) Все app_join Запустить Переход по ссылке
            Приложения и игры app_game_join Играть Переход по ссылке Игры open_url Перейти Переход по ссылке Внешние
            сайты, сообщества, приложения open Открыть Переход по ссылке Внешние сайты more Подробнее Переход по
            ссылке Сообщества call Позвонить Набор номера Телефонные номера book Забронировать Набор номера
            Телефонные номера enroll Записаться Переход по ссылке или набор номера Внешние сайты, телефонные номера
            register Зарегистрироваться Набор номера Телефонные номера buy Купить Переход по ссылке Внешние сайты
            buy_ticket Купить билет Переход по ссылке Внешние сайты order Заказать Переход по ссылке Внешние сайты
            create Создать Переход по ссылке Внешние сайты install Установить Переход по ссылке Внешние сайты contact
            Связаться Переход по ссылке Внешние сайты fill Заполнить Переход по ссылке Внешние сайты join_public
            Подписаться Подписка на публичную страницу Публичные страницы join_event Я пойду Участие в мероприятии
            События join Вступить Вступление в сообщество Сообщества im Связаться Переход к диалогу с сообществом
            Сообщества, публичные страницы, события im2 Написать Переход к диалогу с сообществом Сообщества,
            публичные страницы, события begin Начать Переход по ссылке Внешние сайты get Получить Переход по ссылке
            Внешние сайты watch Смотреть Переход по ссылке Внешние сайты download Скачать Переход по ссылке Внешние
            сайты participate Участвовать Переход по ссылке Внешние сайты play Играть Переход по ссылке Внешние сайты
            apply Подать заявку Переход по ссылке Внешние сайты get_an_offer Получить предложение Переход по ссылке
            Внешние сайты to_write Написать Переход по ссылке Внешние сайты reply Откликнуться Переход по ссылке
            Внешние сайты
        :param link_title: заголовок, который должен быть использован для сниппета. Если не указан, будет
            автоматически получен с целевой ссылки. Обязательно указывать в случае, если ссылка является номером
            телефона.
        :param link_image: ссылка на изображение, которое должно быть использовано для сниппета. Минимальное
            разрешение: 537x240. Если не указана, будет автоматически загружена с целевой ссылки. Обязательно
            указывать в случае, если ссылка является номером телефона. Одновременно может быть указан либо параметр
            link_image, либо параметр link_video.
        :param link_video: идентификатор видео в формате "<owner_id>_<media_id>". Одновременно может быть указан
            либо параметр link_image, либо параметр link_video. Кроме того, параметр link_video может быть указан
            только вместе с параметрами link_button, link_title.

        :return: Идентификатор созданной запис
        """

        params = locals()
        method_name = self._base_method + 'postAdsStealth'
        return self._call(method_name, params)

    def reportComment(self, owner_id: str = None, comment_id: str = None, reason: str = None) -> dict:
        """
        Позволяет пожаловаться на комментарий к записи.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит комментарий.
        :param comment_id: идентификатор комментария.
        :param reason: причина жалобы:   0 — спам;  1 — детская порнография;  2 — экстремизм;  3 — насилие;  4 —
            пропаганда наркотиков;  5 — материал для взрослых;  6 — оскорбление;  8 — призывы к суициду.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reportComment'
        return self._call(method_name, params)

    def reportPost(self, owner_id: str = None, post_id: str = None, reason: str = None) -> dict:
        """
        Позволяет пожаловаться на запись.

        :param owner_id: идентификатор пользователя или сообщества, которому принадлежит запись.
        :param post_id: идентификатор записи.
        :param reason: причина жалобы:   0 — спам;  1 — детская порнография;  2 — экстремизм;  3 — насилие;  4 —
            пропаганда наркотиков;  5 — материал для взрослых;  6 — оскорбление;  8 — призывы к суициду.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reportPost'
        return self._call(method_name, params)

    def repost(self, object: str = None, message: str = None, group_id: str = None, mark_as_ads: str = None,
               mute_notifications: str = None) -> dict:
        """
        Копирует объект на стену пользователя или сообщества.

        :param object: строковый идентификатор объекта, который необходимо разместить на стене, например,
            wall66748_3675 или wall-1_340364.  Формируется из типа объекта (wall, photo, video и т.п.),
            идентификатора владельца объекта и идентификатора самого объекта.
        :param message: сопроводительный текст, который будет добавлен к записи с объектом.
        :param group_id: идентификатор сообщества, на стене которого будет размещена запись с объектом. Если не
            указан, запись будет размещена на стене текущего пользователя.
        :param mark_as_ads: 1 — пометить запись как рекламную.
        :param mute_notifications:

        :return: После успешного выполнения возвращает объект со следующими полями:   success — всегда содержит
            1;  post_id — идентификатор созданной записи;  reposts_count — количество репостов объекта с учетом
            осуществленного;  likes_count — число отметок «Мне нравится» у объекта
        """

        params = locals()
        method_name = self._base_method + 'repost'
        return self._call(method_name, params)

    def restore(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Восстанавливает удаленную запись на стене пользователя или сообщества.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находилась удаленная
            запись. Обратите внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком
            "-" — например, owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'restore'
        return self._call(method_name, params)

    def restoreComment(self, owner_id: str = None, comment_id: str = None) -> dict:
        """
        Восстанавливает удаленный комментарий к записи на стене.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится комментарий к
            записи. Обратите внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком
            "-" — например, owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария на стене.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'restoreComment'
        return self._call(method_name, params)

    def search(self, owner_id: str = None, domain: str = None, query: str = None, owners_only: str = None,
               count: str = None, offset: str = None, extended: str = None, fields: str = None) -> dict:
        """
        Позволяет искать записи на стене в соответствии с заданными критериями.

        :param owner_id: идентификатор пользователя или сообщества. Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param domain: короткий адрес пользователя или сообщества.
        :param query: поисковой запрос. Для точного результата запрос необходимо передавать в двойных кавычках.
        :param owners_only: 1 — возвращать только записи от имени владельца стены.
        :param count: количество записей, которые необходимо вернуть.
        :param offset: смещение, необходимо для получения определенного подмножества результатов.
        :param extended: 1 — в ответе будут возвращены дополнительные поля profiles и groups, содержащие
            информацию о пользователях и сообществах. По умолчанию: 0.
        :param fields: список дополнительных полей для профилей и групп, которые необходимо вернуть. См. описание
            полей объекта user и описание полей объекта group.  Обратите внимание, этот параметр учитывается только
            при extended=1.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов записей на стене в поле items.  Если был задан параметр extended=1, возвращает число результатов
            в поле count, отдельно массив объектов записей на стене в поле items, пользователей в поле profiles и
            сообществ в поле groups
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)

    def unpin(self, owner_id: str = None, post_id: str = None) -> dict:
        """
        Отменяет закрепление записи на стене.

        :param owner_id: идентификатор пользователя или сообщества, на стене которого находится запись. Обратите
            внимание, идентификатор сообщества в параметре owner_id необходимо указывать со знаком "-" — например,
            owner_id=-1 соответствует идентификатору сообщества ВКонтакте API (club1)
        :param post_id: идентификатор записи на стене.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'unpin'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Gifts(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Gifts, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'gifts.'

    def get(self, user_id: str = None, count: str = None, offset: str = None) -> dict:
        """
        Возвращает список полученных подарков пользователя.

        :param user_id: идентификатор пользователя, для которого необходимо получить список подарков.
        :param count: количество подарков, которое нужно вернуть.
        :param offset: смещение, необходимое для выборки определенного подмножества подарков.

        :return: Возвращает список объектов gift_item, каждый из которых содержит следующие поля:   id —
            идентификатор полученного подарка;  from_id — идентификатор пользователя, который отправил подарок, или
            0, если отправитель скрыт;  message — текст сообщения, приложенного к подарку;  date — время отправки
            подарка в формате unixtime;  gift — объект подарка в следующем формате:   id — номер подарка;  thumb_256
            — url изображения подарка размером 256x256px;  thumb_96 — url изображения подарка размером 96x96px;
            thumb_48 — url изображения подарка размером 48x48px;   privacy — значение приватности подарка (только для
            текущего пользователя). Возможные значения:   0 — имя отправителя и сообщение видно всем;  1 — имя
            отправителя видно всем, сообщение видно только получателю;  2 — имя отправителя скрыто, сообщение видно
            только получателю
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)



from ApiMethod import ApiMethod


class Market(ApiMethod):
    def __init__(self, access_token, v, session, calls_per_second):
        super(Market, self).__init__(access_token, v, session, calls_per_second)
        self._base_method = 'market.'

    def add(self, owner_id: str = None, name: str = None, description: str = None, category_id: str = None,
            price: str = None, old_price: str = None, deleted: str = None, main_photo_id: str = None,
            photo_ids: str = None, url: str = None) -> dict:
        """
        Добавляет новый товар.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param name: название товара. Ограничение по длине считается в кодировке cp1251.
        :param description: описание товара.
        :param category_id: идентификатор категории товара.
        :param price: цена товара.
        :param old_price: старая цена товара.
        :param deleted: статус товара (1 — товар удален, 0 — товар не удален).
        :param main_photo_id: идентификатор фотографии обложки товара.  Фотография должна быть загружена с
            помощью метода photos.getMarketUploadServer, передав параметр main_photo. См. подробную информацию о
            загрузке фотографии товаров
        :param photo_ids: идентификаторы дополнительных фотографий товара.  Фотография должна быть загружена с
            помощью метода photos.getMarketUploadServer. См. подробную информацию о загрузке фотографии товаров
        :param url: ссылка на сайт товара.

        :return: После успешного выполнения возвращает идентификатор добавленного товара
        """

        params = locals()
        method_name = self._base_method + 'add'
        return self._call(method_name, params)

    def addAlbum(self, owner_id: str = None, title: str = None, photo_id: str = None, main_album: str = None) -> dict:
        """
        Добавляет новую подборку с товарами.

        :param owner_id: идентификатор владельца подборки.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param title: название подборки.
        :param photo_id: идентификатор фотографии-обложки подборки.  Фотография должна быть загружена с помощью
            метода photos.getMarketAlbumUploadServer. См. подробную информацию о загрузке фотографии товаров.
        :param main_album: назначить подборку основной (1 — назначить, 0 — нет).

        :return: После успешного выполнения возвращает идентификатор созданной подборки
        """

        params = locals()
        method_name = self._base_method + 'addAlbum'
        return self._call(method_name, params)

    def addToAlbum(self, owner_id: str = None, item_id: str = None, album_ids: str = None) -> dict:
        """
        Добавляет товар в одну или несколько выбранных подборок.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.
        :param album_ids: идентификаторы подборок, в которые нужно добавить товар.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'addToAlbum'
        return self._call(method_name, params)

    def createComment(self, owner_id: str = None, item_id: str = None, message: str = None, attachments: str = None,
                      from_group: str = None, reply_to_comment: str = None, sticker_id: str = None,
                      guid: str = None) -> dict:
        """
        Создает новый комментарий к товару.

        :param owner_id: идентификатор владельца товара. Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.
        :param message: текст комментария (является обязательным, если не задан параметр attachments).
        :param attachments: список объектов, приложенных к комментарию и разделённых символом ",". Поле
            attachments представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id> <type> —
            тип медиа-вложения: photo — фотография  video — видеозапись  audio — аудиозапись  doc — документ
            <owner_id> — идентификатор владельца медиа-вложения  <media_id> — идентификатор медиа-вложения.
            Например: photo100172_166443618,photo66748_265827614 Параметр является обязательным, если не задан
            параметр message.
        :param from_group: 1 — комментарий будет опубликован от имени группы, 0 — комментарий будет опубликован
            от имени пользователя (по умолчанию).
        :param reply_to_comment: идентификатор комментария, в ответ на который должен быть добавлен новый
            комментарий.
        :param sticker_id: идентификатор стикера.
        :param guid: уникальный идентификатор, предназначенный для предотвращения повторной отправки одинакового
            комментария.

        :return: После успешного выполнения возвращает идентификатор созданного комментария
        """

        params = locals()
        method_name = self._base_method + 'createComment'
        return self._call(method_name, params)

    def delete(self, owner_id: str = None, item_id: str = None) -> dict:
        """
        Удаляет товар.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'delete'
        return self._call(method_name, params)

    def deleteAlbum(self, owner_id: str = None, album_id: str = None) -> dict:
        """
        Удаляет подборку с товарами.

        :param owner_id: идентификатор владельца подборки.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param album_id: идентификатор подборки.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'deleteAlbum'
        return self._call(method_name, params)

    def deleteComment(self, owner_id: str = None, comment_id: str = None) -> dict:
        """
        Удаляет комментарий к товару.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария.

        :return: После успешного выполнения возвращает 1 (0, если комментарий не найден)
        """

        params = locals()
        method_name = self._base_method + 'deleteComment'
        return self._call(method_name, params)

    def edit(self, owner_id: str = None, item_id: str = None, name: str = None, description: str = None,
             category_id: str = None, price: str = None, old_price: str = None, deleted: str = None,
             main_photo_id: str = None, photo_ids: str = None, url: str = None) -> dict:
        """
        Редактирует товар.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.
        :param name: новое название товара.
        :param description: новое описание товара.
        :param category_id: идентификатор категории товара.
        :param price: цена товара.
        :param old_price: старая цена.
        :param deleted: статус товара (1 — товар удален, 0 — товар не удален).
        :param main_photo_id: идентификатор фотографии для обложки товара.  Фотография может быть загружена с
            помощью метода photos.getMarketUploadServer (параметр main_photo). См. подробную информацию о загрузке
            фотографии товаров.  Идентификатор фотографии может быть также получен методами market.get или
            market.getById (если Вы хотите использовать существующую фотографию товара).
        :param photo_ids: идентификаторы дополнительных фотографией товара.  Фотография должна быть загружена с
            помощью метода photos.getMarketUploadServer. См. подробную информацию о загрузке фотографии товаров.
        :param url: ссылка на сайт товара.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'edit'
        return self._call(method_name, params)

    def editAlbum(self, owner_id: str = None, album_id: str = None, title: str = None, photo_id: str = None,
                  main_album: str = None) -> dict:
        """
        Редактирует подборку с товарами.

        :param owner_id: идентификатор владельца подборки.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param album_id: идентификатор подборки.
        :param title: название подборки.
        :param photo_id: идентификатор фотографии-обложки подборки.  Фотография должна быть загружена с помощью
            метода photos.getMarkeAlbumUploadServer. См. подробную информацию о загрузке фотографии товаров.
        :param main_album: назначить подборку основной (1 — назначить, 0 — нет).

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editAlbum'
        return self._call(method_name, params)

    def editComment(self, owner_id: str = None, comment_id: str = None, message: str = None,
                    attachments: str = None) -> dict:
        """
        Изменяет текст комментария к товару.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария.
        :param message: новый текст комментария (является обязательным, если не задан параметр attachments).
            Максимальное количество символов: 2048.
        :param attachments: новый список объектов, приложенных к комментарию и разделённых символом ",". Поле
            attachments представляется в формате: <type><owner_id>_<media_id>,<type><owner_id>_<media_id> <type> —
            тип медиа-вложения: photo — фотография  video — видеозапись  audio — аудиозапись  doc — документ
            <owner_id> — идентификатор владельца медиа-вложения  <media_id> — идентификатор медиа-вложения.
            Например: photo100172_166443618,photo66748_265827614 Параметр является обязательным, если не задан
            параметр message.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'editComment'
        return self._call(method_name, params)

    def get(self, owner_id: str = None, album_id: str = None, count: str = None, offset: str = None,
            extended: str = None) -> dict:
        """
        Возвращает список товаров в сообществе.

        :param owner_id: идентификатор владельца товаров.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param album_id: идентификатор подборки, товары из которой нужно вернуть.
        :param count: количество возвращаемых товаров.
        :param offset: смещение относительно первого найденного товара для выборки определенного подмножества.
        :param extended: 1 — будут возвращены дополнительные поля likes, can_comment, can_repost, photos,
            views_count. По умолчанию эти поля не возвращается.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов товаров в поле items
        """

        params = locals()
        method_name = self._base_method + 'get'
        return self._call(method_name, params)

    def getAlbumById(self, owner_id: str = None, album_ids: str = None) -> dict:
        """
        Возвращает данные подборки с товарами.

        :param owner_id: идентификатор владельца подборки.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param album_ids: идентификаторы подборок, данные о которых нужно получить.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов подборок в поле items
        """

        params = locals()
        method_name = self._base_method + 'getAlbumById'
        return self._call(method_name, params)

    def getAlbums(self, owner_id: str = None, offset: str = None, count: str = None) -> dict:
        """
        Возвращает список подборок с товарами.

        :param owner_id: идентификатор владельца товаров.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param offset: смещение относительно первой найденной подборки для выборки определенного подмножества.
        :param count: количество возвращаемых подборок.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов подборок в поле items
        """

        params = locals()
        method_name = self._base_method + 'getAlbums'
        return self._call(method_name, params)

    def getById(self, item_ids: str = None, extended: str = None) -> dict:
        """
        Возвращает информацию о товарах по идентификаторам.

        :param item_ids: перечисленные через запятую идентификаторы — идущие через знак подчеркивания id
            владельцев товаров и id самих товаров. Если товар принадлежит сообществу, то в качестве первого параметра
            используется -id сообщества. Пример значения item_ids:  -4363_136089719,13245770_137352259
        :param extended: 1 — будут возвращены дополнительные поля likes, can_comment, can_repost, photos,
            views_count. По умолчанию: 0.

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов товаров в поле items
        """

        params = locals()
        method_name = self._base_method + 'getById'
        return self._call(method_name, params)

    def getCategories(self, count: str = None, offset: str = None) -> dict:
        """
        Возвращает список категорий для товаров.

        :param count: количество категорий, информацию о которых необходимо вернуть.
        :param offset: смещение, необходимое для выборки определенного подмножества категорий.

        :return: После успешного выполнения возвращает список объектов category.  Объект category — категория
            товара.  id   (integer) идентификатор категории. name   (string) название метки. section   (object)
            секция. Объект, содержащий поля:   id (integer) — идентификатор секции;  name (string) — название секции
        """

        params = locals()
        method_name = self._base_method + 'getCategories'
        return self._call(method_name, params)

    def getComments(self, owner_id: str = None, item_id: str = None, need_likes: str = None,
                    start_comment_id: str = None, offset: str = None, count: str = None, sort: str = None,
                    extended: str = None, fields: str = None) -> dict:
        """
        Возвращает список комментариев к товару.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.
        :param need_likes: 1 — возвращать информацию о лайках.
        :param start_comment_id: идентификатор комментария, начиная с которого нужно вернуть список (подробности
            см. ниже).
        :param offset: сдвиг, необходимый для получения конкретной выборки результатов.
        :param count: число комментариев, которые необходимо получить.
        :param sort: порядок сортировки комментариев (asc — от старых к новым, desc - от новых к старым)
        :param extended: 1 — комментарии в ответе будут возвращены в виде пронумерованных объектов, дополнительно
            будут возвращены списки объектов profiles, groups.
        :param fields: список дополнительных полей профилей, которые необходимо вернуть. См. подробное описание.
            Доступные значения: sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200,
            photo_400_orig, photo_max, photo_max_orig, photo_id, online, online_mobile, domain, has_mobile, contacts,
            connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio,
            can_write_private_message, status, last_seen, common_count, relation, relatives, counters, screen_name,
            maiden_name, timezone, occupation,activities, interests, music, movies, tv, books, games, about, quotes,
            personal, friend_status, military, career

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов комментариев в поле items
        """

        params = locals()
        method_name = self._base_method + 'getComments'
        return self._call(method_name, params)

    def removeFromAlbum(self, owner_id: str = None, item_id: str = None, album_ids: str = None) -> dict:
        """
        Удаляет товар из одной или нескольких выбранных подборок.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.
        :param album_ids: идентификаторы подборок, из которых нужно удалить товар.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'removeFromAlbum'
        return self._call(method_name, params)

    def reorderAlbums(self, owner_id: str = None, album_id: str = None, before: str = None, after: str = None) -> dict:
        """
        Изменяет положение подборки с товарами в списке.

        :param owner_id: идентификатор владельца альбома.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param album_id: идентификатор подборки.
        :param before: идентификатор подборки, перед которой следует поместить текущую.
        :param after: идентификатор подборки, после которой следует поместить текущую.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reorderAlbums'
        return self._call(method_name, params)

    def reorderItems(self, owner_id: str = None, album_id: str = None, item_id: str = None, before: str = None,
                     after: str = None) -> dict:
        """
        Изменяет положение товара в подборке.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param album_id: идентификатор подборки, в которой находится товар. 0 — для сортировки общего списка
            товаров.
        :param item_id: идентификатор товара.
        :param before: идентификатор товара, перед которым следует поместить текущий.
        :param after: идентификатор товара, после которого следует поместить текущий.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reorderItems'
        return self._call(method_name, params)

    def report(self, owner_id: str = None, item_id: str = None, reason: str = None) -> dict:
        """
        Позволяет отправить жалобу на товар.

        :param owner_id: идентификатор владельца товаров.  Обратите внимание, идентификатор сообщества в
            параметре owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует
            идентификатору сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара
        :param reason: причина жалобы:   0 — спам;  1 — детская порнография;  2 — экстремизм;  3 — насилие;  4 —
            пропаганда наркотиков;  5 — материал для взрослых;  6 — оскорбление.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'report'
        return self._call(method_name, params)

    def reportComment(self, owner_id: str = None, comment_id: str = None, reason: str = None) -> dict:
        """
        Позволяет оставить жалобу на комментарий к товару.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор комментария.
        :param reason: причина жалобы:   0 — спам;  1 — детская порнография;  2 — экстремизм;  3 — насилие;  4 —
            пропаганда наркотиков;  5 — материал для взрослых;  6 — оскорбление.

        :return: После успешного выполнения возвращает 1
        """

        params = locals()
        method_name = self._base_method + 'reportComment'
        return self._call(method_name, params)

    def restore(self, owner_id: str = None, item_id: str = None) -> dict:
        """
        Восстанавливает удаленный товар.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param item_id: идентификатор товара.

        :return: После успешного выполнения возвращает 1 (0, если товар не найден среди удаленных)
        """

        params = locals()
        method_name = self._base_method + 'restore'
        return self._call(method_name, params)

    def restoreComment(self, owner_id: str = None, comment_id: str = None) -> dict:
        """
        Восстанавливает удаленный комментарий к товару.

        :param owner_id: идентификатор владельца товара.  Обратите внимание, идентификатор сообщества в параметре
            owner_id необходимо указывать со знаком "-" — например, owner_id=-1 соответствует идентификатору
            сообщества ВКонтакте API (club1)
        :param comment_id: идентификатор удаленного комментария.

        :return: После успешного выполнения возвращает 1 (0, если комментарий с таким идентификатором не является
            удаленным)
        """

        params = locals()
        method_name = self._base_method + 'restoreComment'
        return self._call(method_name, params)

    def search(self, owner_id: str = None, album_id: str = None, q: str = None, price_from: str = None,
               price_to: str = None, tags: str = None, sort: str = None, rev: str = None, offset: str = None,
               count: str = None, extended: str = None, status: str = None) -> dict:
        """
        Ищет товары в каталоге сообщества.

        :param owner_id: идентификатор сообщества, которому принадлежат товары.
        :param album_id: идентификатор подборки, товары из которой нужно вернуть.
        :param q:  поискового запроса. Например, зеленые тапочки.
        :param price_from: минимальное значение цены товаров в сотых долях единицы валюты. Например, 100000.
        :param price_to: максимальное значение цены товаров в сотых долях единицы валюты. Например, 1410000.
        :param tags: перечисленные через запятую идентификаторы меток.
        :param sort: вид сортировки. 0 — пользовательская расстановка, 1 — по дате добавления товара, 2 — по
            цене, 3 — по популярности.
        :param rev: 0 — не использовать обратный порядок, 1 — использовать обратный порядок.
        :param offset: смещение относительно первого найденного товара для выборки определенного подмножества.
        :param count: количество возвращаемых товаров.
        :param extended: 1 — будут возвращены дополнительные поля likes, can_comment, can_repost, photos,
            views_count. По умолчанию эти поля не возвращается.
        :param status:

        :return: После успешного выполнения возвращает объект, содержащий число результатов в поле count и массив
            объектов товаров в поле items
        """

        params = locals()
        method_name = self._base_method + 'search'
        return self._call(method_name, params)
